# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/fields/core_types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/dbtlabs/proto/public/v1/fields/core_types.proto\x12\x1bv1.public.fields.core_types\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xa9\x02\n\rCoreEventInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\t\x12\x15\n\rinvocation_id\x18\x05 \x01(\t\x12\x0b\n\x03pid\x18\x06 \x01(\x05\x12\x0e\n\x06thread\x18\x07 \x01(\t\x12&\n\x02ts\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x44\n\x05\x65xtra\x18\t \x03(\x0b\x32\x35.v1.public.fields.core_types.CoreEventInfo.ExtraEntry\x12\x10\n\x08\x63\x61tegory\x18\n \x01(\t\x1a,\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"V\n\x0cNodeRelation\x12\x10\n\x08\x64\x61tabase\x18\n \x01(\t\x12\x0e\n\x06schema\x18\x0b \x01(\t\x12\r\n\x05\x61lias\x18\x0c \x01(\t\x12\x15\n\rrelation_name\x18\r \x01(\t\"\xb8\x02\n\x08NodeInfo\x12\x11\n\tnode_path\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12\x11\n\tunique_id\x18\x03 \x01(\t\x12\x15\n\rresource_type\x18\x04 \x01(\t\x12\x14\n\x0cmaterialized\x18\x05 \x01(\t\x12\x13\n\x0bnode_status\x18\x06 \x01(\t\x12\x17\n\x0fnode_started_at\x18\x07 \x01(\t\x12\x18\n\x10node_finished_at\x18\x08 \x01(\t\x12%\n\x04meta\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12@\n\rnode_relation\x18\n \x01(\x0b\x32).v1.public.fields.core_types.NodeRelation\x12\x15\n\rnode_checksum\x18\x0b \x01(\t\"\x7f\n\rTimingInfoMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\nstarted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63ompleted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xe1\x01\n\x0cRunResultMsg\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12?\n\x0btiming_info\x18\x03 \x03(\x0b\x32*.v1.public.fields.core_types.TimingInfoMsg\x12\x0e\n\x06thread\x18\x04 \x01(\t\x12\x16\n\x0e\x65xecution_time\x18\x05 \x01(\x02\x12\x31\n\x10\x61\x64\x61pter_response\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x14\n\x0cnum_failures\x18\x07 \x01(\x05\"\\\n\nColumnType\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x1c\n\x14previous_column_type\x18\x02 \x01(\t\x12\x1b\n\x13\x63urrent_column_type\x18\x03 \x01(\t\"Y\n\x10\x43olumnConstraint\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x17\n\x0f\x63onstraint_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63onstraint_type\x18\x03 \x01(\t\"T\n\x0fModelConstraint\x12\x17\n\x0f\x63onstraint_name\x18\x01 \x01(\t\x12\x17\n\x0f\x63onstraint_type\x18\x02 \x01(\t\x12\x0f\n\x07\x63olumns\x18\x03 \x03(\t\"9\n\x11MainReportVersion\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x13\n\x0blog_version\x18\x02 \x01(\x05\"\x8e\x01\n\x14MainReportVersionMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..v1.public.fields.core_types.MainReportVersion\"\x82\x01\n\x0eMainReportArgs\x12\x43\n\x04\x61rgs\x18\x01 \x03(\x0b\x32\x35.v1.public.fields.core_types.MainReportArgs.ArgsEntry\x1a+\n\tArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x01\n\x11MainReportArgsMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.v1.public.fields.core_types.MainReportArgs\"+\n\x15MainTrackingUserState\x12\x12\n\nuser_state\x18\x01 \x01(\t\"\x96\x01\n\x18MainTrackingUserStateMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.v1.public.fields.core_types.MainTrackingUserState\"5\n\x0fMergedFromState\x12\x12\n\nnum_merged\x18\x01 \x01(\x05\x12\x0e\n\x06sample\x18\x02 \x03(\t\"\x8a\x01\n\x12MergedFromStateMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.v1.public.fields.core_types.MergedFromState\"A\n\x14MissingProfileTarget\x12\x14\n\x0cprofile_name\x18\x01 \x01(\t\x12\x13\n\x0btarget_name\x18\x02 \x01(\t\"\x94\x01\n\x17MissingProfileTargetMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.v1.public.fields.core_types.MissingProfileTarget\"(\n\x11InvalidOptionYAML\x12\x13\n\x0boption_name\x18\x01 \x01(\t\"\x8e\x01\n\x14InvalidOptionYAMLMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..v1.public.fields.core_types.InvalidOptionYAML\"!\n\x12LogDbtProjectError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"\x90\x01\n\x15LogDbtProjectErrorMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.v1.public.fields.core_types.LogDbtProjectError\"3\n\x12LogDbtProfileError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\x12\x10\n\x08profiles\x18\x02 \x03(\t\"\x90\x01\n\x15LogDbtProfileErrorMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.v1.public.fields.core_types.LogDbtProfileError\"!\n\x12StarterProjectPath\x12\x0b\n\x03\x64ir\x18\x01 \x01(\t\"\x90\x01\n\x15StarterProjectPathMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.v1.public.fields.core_types.StarterProjectPath\"$\n\x15\x43onfigFolderDirectory\x12\x0b\n\x03\x64ir\x18\x01 \x01(\t\"\x96\x01\n\x18\x43onfigFolderDirectoryMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.v1.public.fields.core_types.ConfigFolderDirectory\"\'\n\x14NoSampleProfileFound\x12\x0f\n\x07\x61\x64\x61pter\x18\x01 \x01(\t\"\x94\x01\n\x17NoSampleProfileFoundMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.v1.public.fields.core_types.NoSampleProfileFound\"6\n\x18ProfileWrittenWithSample\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\x9c\x01\n\x1bProfileWrittenWithSampleMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x43\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x35.v1.public.fields.core_types.ProfileWrittenWithSample\"B\n$ProfileWrittenWithTargetTemplateYAML\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\xb4\x01\n\'ProfileWrittenWithTargetTemplateYAMLMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12O\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x41.v1.public.fields.core_types.ProfileWrittenWithTargetTemplateYAML\"C\n%ProfileWrittenWithProjectTemplateYAML\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\xb6\x01\n(ProfileWrittenWithProjectTemplateYAMLMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12P\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x42.v1.public.fields.core_types.ProfileWrittenWithProjectTemplateYAML\"\x12\n\x10SettingUpProfile\"\x8c\x01\n\x13SettingUpProfileMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.v1.public.fields.core_types.SettingUpProfile\"\x1c\n\x1aInvalidProfileTemplateYAML\"\xa0\x01\n\x1dInvalidProfileTemplateYAMLMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x45\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x37.v1.public.fields.core_types.InvalidProfileTemplateYAML\"(\n\x18ProjectNameAlreadyExists\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x9c\x01\n\x1bProjectNameAlreadyExistsMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x43\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x35.v1.public.fields.core_types.ProjectNameAlreadyExists\"K\n\x0eProjectCreated\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\x12\x10\n\x08\x64ocs_url\x18\x02 \x01(\t\x12\x11\n\tslack_url\x18\x03 \x01(\t\"\x88\x01\n\x11ProjectCreatedMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.v1.public.fields.core_types.ProjectCreated\"@\n\x1aPackageRedirectDeprecation\x12\x10\n\x08old_name\x18\x01 \x01(\t\x12\x10\n\x08new_name\x18\x02 \x01(\t\"\xa0\x01\n\x1dPackageRedirectDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x45\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x37.v1.public.fields.core_types.PackageRedirectDeprecation\"\x1f\n\x1dPackageInstallPathDeprecation\"\xa6\x01\n PackageInstallPathDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12H\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32:.v1.public.fields.core_types.PackageInstallPathDeprecation\"H\n\x1b\x43onfigSourcePathDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\x12\x10\n\x08\x65xp_path\x18\x02 \x01(\t\"\xa2\x01\n\x1e\x43onfigSourcePathDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x46\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x38.v1.public.fields.core_types.ConfigSourcePathDeprecation\"F\n\x19\x43onfigDataPathDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\x12\x10\n\x08\x65xp_path\x18\x02 \x01(\t\"\x9e\x01\n\x1c\x43onfigDataPathDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x44\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x36.v1.public.fields.core_types.ConfigDataPathDeprecation\".\n\x17MetricAttributesRenamed\x12\x13\n\x0bmetric_name\x18\x01 \x01(\t\"\x9a\x01\n\x1aMetricAttributesRenamedMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x42\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x34.v1.public.fields.core_types.MetricAttributesRenamed\"+\n\x17\x45xposureNameDeprecation\x12\x10\n\x08\x65xposure\x18\x01 \x01(\t\"\x9a\x01\n\x1a\x45xposureNameDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x42\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x34.v1.public.fields.core_types.ExposureNameDeprecation\"^\n\x13InternalDeprecation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x18\n\x10suggested_action\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"\x92\x01\n\x16InternalDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.core_types.InternalDeprecation\"@\n\x1a\x45nvironmentVariableRenamed\x12\x10\n\x08old_name\x18\x01 \x01(\t\x12\x10\n\x08new_name\x18\x02 \x01(\t\"\xa0\x01\n\x1d\x45nvironmentVariableRenamedMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x45\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x37.v1.public.fields.core_types.EnvironmentVariableRenamed\"3\n\x18\x43onfigLogPathDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\"\x9c\x01\n\x1b\x43onfigLogPathDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x43\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x35.v1.public.fields.core_types.ConfigLogPathDeprecation\"6\n\x1b\x43onfigTargetPathDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\"\xa2\x01\n\x1e\x43onfigTargetPathDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x46\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x38.v1.public.fields.core_types.ConfigTargetPathDeprecation\"C\n\x16TestsConfigDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\x12\x10\n\x08\x65xp_path\x18\x02 \x01(\t\"\x98\x01\n\x19TestsConfigDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x41\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x33.v1.public.fields.core_types.TestsConfigDeprecation\"\x1e\n\x1cProjectFlagsMovedDeprecation\"\xa4\x01\n\x1fProjectFlagsMovedDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12G\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x39.v1.public.fields.core_types.ProjectFlagsMovedDeprecation\"C\n\x1fSpacesInResourceNameDeprecation\x12\x11\n\tunique_id\x18\x01 \x01(\t\x12\r\n\x05level\x18\x02 \x01(\t\"\xaa\x01\n\"SpacesInResourceNameDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12J\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32<.v1.public.fields.core_types.SpacesInResourceNameDeprecation\"i\n\"ResourceNamesWithSpacesDeprecation\x12\x1b\n\x13\x63ount_invalid_names\x18\x01 \x01(\x05\x12\x17\n\x0fshow_debug_hint\x18\x02 \x01(\x08\x12\r\n\x05level\x18\x03 \x01(\t\"\xb0\x01\n%ResourceNamesWithSpacesDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12M\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32?.v1.public.fields.core_types.ResourceNamesWithSpacesDeprecation\"_\n)PackageMaterializationOverrideDeprecation\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x1c\n\x14materialization_name\x18\x02 \x01(\t\"\xbe\x01\n,PackageMaterializationOverrideDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12T\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x46.v1.public.fields.core_types.PackageMaterializationOverrideDeprecation\"#\n!SourceFreshnessProjectHooksNotRun\"\xae\x01\n$SourceFreshnessProjectHooksNotRunMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12L\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32>.v1.public.fields.core_types.SourceFreshnessProjectHooksNotRun\"0\n.MFTimespineWithoutYamlConfigurationDeprecation\"\xc8\x01\n1MFTimespineWithoutYamlConfigurationDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12Y\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32K.v1.public.fields.core_types.MFTimespineWithoutYamlConfigurationDeprecation\"#\n!MFCumulativeTypeParamsDeprecation\"\xae\x01\n$MFCumulativeTypeParamsDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12L\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32>.v1.public.fields.core_types.MFCumulativeTypeParamsDeprecation\",\n*MicrobatchMacroOutsideOfBatchesDeprecation\"\xc0\x01\n-MicrobatchMacroOutsideOfBatchesDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12U\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32G.v1.public.fields.core_types.MicrobatchMacroOutsideOfBatchesDeprecation\"[\n&GenericJSONSchemaValidationDeprecation\x12\x11\n\tviolation\x18\x01 \x01(\t\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\x12\x10\n\x08key_path\x18\x03 \x01(\t\"\xb8\x01\n)GenericJSONSchemaValidationDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12Q\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x43.v1.public.fields.core_types.GenericJSONSchemaValidationDeprecation\"<\n\x1fUnexpectedJinjaBlockDeprecation\x12\x0b\n\x03msg\x18\x01 \x01(\t\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\"\xaa\x01\n\"UnexpectedJinjaBlockDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12J\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32<.v1.public.fields.core_types.UnexpectedJinjaBlockDeprecation\"K\n\x1c\x44uplicateYAMLKeysDeprecation\x12\x1d\n\x15\x64uplicate_description\x18\x01 \x01(\t\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\"\xa4\x01\n\x1f\x44uplicateYAMLKeysDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12G\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x39.v1.public.fields.core_types.DuplicateYAMLKeysDeprecation\"9\n\x1c\x43ustomTopLevelKeyDeprecation\x12\x0b\n\x03msg\x18\x01 \x01(\t\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\"\xa4\x01\n\x1f\x43ustomTopLevelKeyDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12G\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x39.v1.public.fields.core_types.CustomTopLevelKeyDeprecation\"K\n\x1c\x43ustomKeyInConfigDeprecation\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\x12\x10\n\x08key_path\x18\x03 \x01(\t\"\xa4\x01\n\x1f\x43ustomKeyInConfigDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12G\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x39.v1.public.fields.core_types.CustomKeyInConfigDeprecation\"K\n\x1c\x43ustomKeyInObjectDeprecation\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\x12\x10\n\x08key_path\x18\x03 \x01(\t\"\xa4\x01\n\x1f\x43ustomKeyInObjectDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12G\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x39.v1.public.fields.core_types.CustomKeyInObjectDeprecation\"Q\n\x12\x44\x65precationSummary\x12\x12\n\nevent_name\x18\x01 \x01(\t\x12\x12\n\nevent_code\x18\x02 \x01(\t\x12\x13\n\x0boccurrences\x18\x03 \x01(\x05\"p\n\x13\x44\x65precationsSummary\x12\x42\n\tsummaries\x18\x01 \x03(\x0b\x32/.v1.public.fields.core_types.DeprecationSummary\x12\x15\n\rshow_all_hint\x18\x02 \x01(\x08\"\x92\x01\n\x16\x44\x65precationsSummaryMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.core_types.DeprecationsSummary\"<\n,CustomOutputPathInSourceFreshnessDeprecation\x12\x0c\n\x04path\x18\x01 \x01(\t\"\xc4\x01\n/CustomOutputPathInSourceFreshnessDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12W\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32I.v1.public.fields.core_types.CustomOutputPathInSourceFreshnessDeprecation\"O\n PropertyMovedToConfigDeprecation\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\x12\x10\n\x08key_path\x18\x03 \x01(\t\"\xac\x01\n#PropertyMovedToConfigDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12K\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32=.v1.public.fields.core_types.PropertyMovedToConfigDeprecation\"L\n\x1cWEOIncludeExcludeDeprecation\x12\x15\n\rfound_include\x18\x01 \x01(\x08\x12\x15\n\rfound_exclude\x18\x02 \x01(\x08\"\xa4\x01\n\x1fWEOIncludeExcludeDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12G\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x39.v1.public.fields.core_types.WEOIncludeExcludeDeprecation\"\x1c\n\x1aModelParamUsageDeprecation\"\xa0\x01\n\x1dModelParamUsageDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x45\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x37.v1.public.fields.core_types.ModelParamUsageDeprecation\"$\n\"ResourceTypesParamUsageDeprecation\"\xb0\x01\n%ResourceTypesParamUsageDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12M\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32?.v1.public.fields.core_types.ResourceTypesParamUsageDeprecation\"\"\n ModulesItertoolsUsageDeprecation\"\xac\x01\n#ModulesItertoolsUsageDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12K\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32=.v1.public.fields.core_types.ModulesItertoolsUsageDeprecation\">\n\x19SourceOverrideDeprecation\x12\x13\n\x0bsource_name\x18\x01 \x01(\t\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\"\x9e\x01\n\x1cSourceOverrideDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x44\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x36.v1.public.fields.core_types.SourceOverrideDeprecation\"S\n\'EnvironmentVariableNamespaceDeprecation\x12\x0f\n\x07\x65nv_var\x18\x01 \x01(\t\x12\x17\n\x0freserved_prefix\x18\x02 \x01(\t\"\xba\x01\n*EnvironmentVariableNamespaceDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12R\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x44.v1.public.fields.core_types.EnvironmentVariableNamespaceDeprecation\"K\n\x1cMissingPlusPrefixDeprecation\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\x12\x10\n\x08key_path\x18\x03 \x01(\t\"\xa4\x01\n\x1fMissingPlusPrefixDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12G\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x39.v1.public.fields.core_types.MissingPlusPrefixDeprecation\"4\n$ArgsPropertyInGenericTestDeprecation\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\"\xb4\x01\n\'ArgsPropertyInGenericTestDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12O\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x41.v1.public.fields.core_types.ArgsPropertyInGenericTestDeprecation\">\n)ArgumentsPropertyInGenericTestDeprecation\x12\x11\n\ttest_name\x18\x01 \x01(\t\"\xbe\x01\n,ArgumentsPropertyInGenericTestDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12T\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x46.v1.public.fields.core_types.ArgumentsPropertyInGenericTestDeprecation\"E\n0MissingArgumentsPropertyInGenericTestDeprecation\x12\x11\n\ttest_name\x18\x01 \x01(\t\"\xcc\x01\n3MissingArgumentsPropertyInGenericTestDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12[\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32M.v1.public.fields.core_types.MissingArgumentsPropertyInGenericTestDeprecation\"\x80\x01\n)DuplicateNameDistinctNodeTypesDeprecation\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\x14\n\x0cpackage_name\x18\x02 \x01(\t\x12\x12\n\nunique_id1\x18\x03 \x01(\t\x12\x12\n\nunique_id2\x18\x04 \x01(\t\"\xbe\x01\n,DuplicateNameDistinctNodeTypesDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12T\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x46.v1.public.fields.core_types.DuplicateNameDistinctNodeTypesDeprecation\"V\n\x0f\x44\x65precatedModel\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x15\n\rmodel_version\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65precation_date\x18\x03 \x01(\t\"\x8a\x01\n\x12\x44\x65precatedModelMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.v1.public.fields.core_types.DeprecatedModel\"7\n\x12InputFileDiffError\x12\x10\n\x08\x63\x61tegory\x18\x01 \x01(\t\x12\x0f\n\x07\x66ile_id\x18\x02 \x01(\t\"\x90\x01\n\x15InputFileDiffErrorMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.v1.public.fields.core_types.InputFileDiffError\"?\n\x14InvalidValueForField\x12\x12\n\nfield_name\x18\x01 \x01(\t\x12\x13\n\x0b\x66ield_value\x18\x02 \x01(\t\"\x94\x01\n\x17InvalidValueForFieldMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.v1.public.fields.core_types.InvalidValueForField\"Q\n\x11ValidationWarning\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x12\n\nfield_name\x18\x02 \x01(\t\x12\x11\n\tnode_name\x18\x03 \x01(\t\"\x8e\x01\n\x14ValidationWarningMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..v1.public.fields.core_types.ValidationWarning\"!\n\x11ParsePerfInfoPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x8e\x01\n\x14ParsePerfInfoPathMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..v1.public.fields.core_types.ParsePerfInfoPath\"1\n!PartialParsingErrorProcessingFile\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\"\xae\x01\n$PartialParsingErrorProcessingFileMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12L\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32>.v1.public.fields.core_types.PartialParsingErrorProcessingFile\"\x96\x01\n\x13PartialParsingError\x12O\n\x08\x65xc_info\x18\x01 \x03(\x0b\x32=.v1.public.fields.core_types.PartialParsingError.ExcInfoEntry\x1a.\n\x0c\x45xcInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x92\x01\n\x16PartialParsingErrorMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.core_types.PartialParsingError\"\x1b\n\x19PartialParsingSkipParsing\"\x9e\x01\n\x1cPartialParsingSkipParsingMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x44\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x36.v1.public.fields.core_types.PartialParsingSkipParsing\"&\n\x14UnableToPartialParse\x12\x0e\n\x06reason\x18\x01 \x01(\t\"\x94\x01\n\x17UnableToPartialParseMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.v1.public.fields.core_types.UnableToPartialParse\"f\n\x12StateCheckVarsHash\x12\x10\n\x08\x63hecksum\x18\x01 \x01(\t\x12\x0c\n\x04vars\x18\x02 \x01(\t\x12\x0f\n\x07profile\x18\x03 \x01(\t\x12\x0e\n\x06target\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\"\x90\x01\n\x15StateCheckVarsHashMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.v1.public.fields.core_types.StateCheckVarsHash\"\x1a\n\x18PartialParsingNotEnabled\"\x9c\x01\n\x1bPartialParsingNotEnabledMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x43\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x35.v1.public.fields.core_types.PartialParsingNotEnabled\"C\n\x14ParsedFileLoadFailed\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x03 \x01(\t\"\x94\x01\n\x17ParsedFileLoadFailedMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.v1.public.fields.core_types.ParsedFileLoadFailed\"H\n\x15PartialParsingEnabled\x12\x0f\n\x07\x64\x65leted\x18\x01 \x01(\x05\x12\r\n\x05\x61\x64\x64\x65\x64\x18\x02 \x01(\x05\x12\x0f\n\x07\x63hanged\x18\x03 \x01(\x05\"\x96\x01\n\x18PartialParsingEnabledMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.v1.public.fields.core_types.PartialParsingEnabled\"8\n\x12PartialParsingFile\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12\x11\n\toperation\x18\x02 \x01(\t\"\x90\x01\n\x15PartialParsingFileMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.v1.public.fields.core_types.PartialParsingFile\"\xaf\x01\n\x1fInvalidDisabledTargetInTestNode\x12\x1b\n\x13resource_type_title\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x12\x1a\n\x12original_file_path\x18\x03 \x01(\t\x12\x13\n\x0btarget_kind\x18\x04 \x01(\t\x12\x13\n\x0btarget_name\x18\x05 \x01(\t\x12\x16\n\x0etarget_package\x18\x06 \x01(\t\"\xaa\x01\n\"InvalidDisabledTargetInTestNodeMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12J\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32<.v1.public.fields.core_types.InvalidDisabledTargetInTestNode\"7\n\x18UnusedResourceConfigPath\x12\x1b\n\x13unused_config_paths\x18\x01 \x03(\t\"\x9c\x01\n\x1bUnusedResourceConfigPathMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x43\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x35.v1.public.fields.core_types.UnusedResourceConfigPath\"3\n\rSeedIncreased\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x86\x01\n\x10SeedIncreasedMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.v1.public.fields.core_types.SeedIncreased\">\n\x18SeedExceedsLimitSamePath\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x9c\x01\n\x1bSeedExceedsLimitSamePathMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x43\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x35.v1.public.fields.core_types.SeedExceedsLimitSamePath\"D\n\x1eSeedExceedsLimitAndPathChanged\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xa8\x01\n!SeedExceedsLimitAndPathChangedMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12I\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32;.v1.public.fields.core_types.SeedExceedsLimitAndPathChanged\"\\\n\x1fSeedExceedsLimitChecksumChanged\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rchecksum_name\x18\x03 \x01(\t\"\xaa\x01\n\"SeedExceedsLimitChecksumChangedMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12J\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32<.v1.public.fields.core_types.SeedExceedsLimitChecksumChanged\"%\n\x0cUnusedTables\x12\x15\n\runused_tables\x18\x01 \x03(\t\"\x84\x01\n\x0fUnusedTablesMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).v1.public.fields.core_types.UnusedTables\"\x87\x01\n\x17WrongResourceSchemaFile\x12\x12\n\npatch_name\x18\x01 \x01(\t\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x1c\n\x14plural_resource_type\x18\x03 \x01(\t\x12\x10\n\x08yaml_key\x18\x04 \x01(\t\x12\x11\n\tfile_path\x18\x05 \x01(\t\"\x9a\x01\n\x1aWrongResourceSchemaFileMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x42\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x34.v1.public.fields.core_types.WrongResourceSchemaFile\"K\n\x10NoNodeForYamlKey\x12\x12\n\npatch_name\x18\x01 \x01(\t\x12\x10\n\x08yaml_key\x18\x02 \x01(\t\x12\x11\n\tfile_path\x18\x03 \x01(\t\"\x8c\x01\n\x13NoNodeForYamlKeyMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.v1.public.fields.core_types.NoNodeForYamlKey\"+\n\x15MacroNotFoundForPatch\x12\x12\n\npatch_name\x18\x01 \x01(\t\"\x96\x01\n\x18MacroNotFoundForPatchMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.v1.public.fields.core_types.MacroNotFoundForPatch\"\xb8\x01\n\x16NodeNotFoundOrDisabled\x12\x1a\n\x12original_file_path\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x12\x1b\n\x13resource_type_title\x18\x03 \x01(\t\x12\x13\n\x0btarget_name\x18\x04 \x01(\t\x12\x13\n\x0btarget_kind\x18\x05 \x01(\t\x12\x16\n\x0etarget_package\x18\x06 \x01(\t\x12\x10\n\x08\x64isabled\x18\x07 \x01(\t\"\x98\x01\n\x19NodeNotFoundOrDisabledMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x41\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x33.v1.public.fields.core_types.NodeNotFoundOrDisabled\"X\n\x0fJinjaLogWarning\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x8a\x01\n\x12JinjaLogWarningMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.v1.public.fields.core_types.JinjaLogWarning\"U\n\x0cJinjaLogInfo\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x84\x01\n\x0fJinjaLogInfoMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).v1.public.fields.core_types.JinjaLogInfo\"V\n\rJinjaLogDebug\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x86\x01\n\x10JinjaLogDebugMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.v1.public.fields.core_types.JinjaLogDebug\"\xbe\x01\n\x1eUnpinnedRefNewVersionAvailable\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x15\n\rref_node_name\x18\x02 \x01(\t\x12\x18\n\x10ref_node_package\x18\x03 \x01(\t\x12\x18\n\x10ref_node_version\x18\x04 \x01(\t\x12\x17\n\x0fref_max_version\x18\x05 \x01(\t\"\xa8\x01\n!UnpinnedRefNewVersionAvailableMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12I\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32;.v1.public.fields.core_types.UnpinnedRefNewVersionAvailable\"\xc6\x01\n\x1cUpcomingReferenceDeprecation\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x19\n\x11ref_model_package\x18\x02 \x01(\t\x12\x16\n\x0eref_model_name\x18\x03 \x01(\t\x12\x19\n\x11ref_model_version\x18\x04 \x01(\t\x12 \n\x18ref_model_latest_version\x18\x05 \x01(\t\x12\"\n\x1aref_model_deprecation_date\x18\x06 \x01(\t\"\xa4\x01\n\x1fUpcomingReferenceDeprecationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12G\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x39.v1.public.fields.core_types.UpcomingReferenceDeprecation\"\xbd\x01\n\x13\x44\x65precatedReference\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x19\n\x11ref_model_package\x18\x02 \x01(\t\x12\x16\n\x0eref_model_name\x18\x03 \x01(\t\x12\x19\n\x11ref_model_version\x18\x04 \x01(\t\x12 \n\x18ref_model_latest_version\x18\x05 \x01(\t\x12\"\n\x1aref_model_deprecation_date\x18\x06 \x01(\t\"\x92\x01\n\x16\x44\x65precatedReferenceMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.core_types.DeprecatedReference\"<\n$UnsupportedConstraintMaterialization\x12\x14\n\x0cmaterialized\x18\x01 \x01(\t\"\xb4\x01\n\'UnsupportedConstraintMaterializationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12O\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x41.v1.public.fields.core_types.UnsupportedConstraintMaterialization\"]\n\x14ParseInlineNodeError\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\"\x94\x01\n\x17ParseInlineNodeErrorMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.v1.public.fields.core_types.ParseInlineNodeError\"(\n\x19SemanticValidationFailure\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x9e\x01\n\x1cSemanticValidationFailureMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x44\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x36.v1.public.fields.core_types.SemanticValidationFailure\"\xba\x03\n\x19UnversionedBreakingChange\x12\x18\n\x10\x62reaking_changes\x18\x01 \x03(\t\x12\x12\n\nmodel_name\x18\x02 \x01(\t\x12\x17\n\x0fmodel_file_path\x18\x03 \x01(\t\x12\"\n\x1a\x63ontract_enforced_disabled\x18\x04 \x01(\x08\x12\x17\n\x0f\x63olumns_removed\x18\x05 \x03(\t\x12\x44\n\x13\x63olumn_type_changes\x18\x06 \x03(\x0b\x32\'.v1.public.fields.core_types.ColumnType\x12Y\n\"enforced_column_constraint_removed\x18\x07 \x03(\x0b\x32-.v1.public.fields.core_types.ColumnConstraint\x12W\n!enforced_model_constraint_removed\x18\x08 \x03(\x0b\x32,.v1.public.fields.core_types.ModelConstraint\x12\x1f\n\x17materialization_changed\x18\t \x03(\t\"\x9e\x01\n\x1cUnversionedBreakingChangeMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x44\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x36.v1.public.fields.core_types.UnversionedBreakingChange\"*\n\x14WarnStateTargetEqual\x12\x12\n\nstate_path\x18\x01 \x01(\t\"\x94\x01\n\x17WarnStateTargetEqualMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.v1.public.fields.core_types.WarnStateTargetEqual\"%\n\x16\x46reshnessConfigProblem\x12\x0b\n\x03msg\x18\x01 \x01(\t\"\x98\x01\n\x19\x46reshnessConfigProblemMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x41\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x33.v1.public.fields.core_types.FreshnessConfigProblem\"6\n MicrobatchModelNoEventTimeInputs\x12\x12\n\nmodel_name\x18\x01 \x01(\t\"\xac\x01\n#MicrobatchModelNoEventTimeInputsMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12K\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32=.v1.public.fields.core_types.MicrobatchModelNoEventTimeInputs\"J\n\x1eInvalidConcurrentBatchesConfig\x12\x12\n\nnum_models\x18\x01 \x01(\x05\x12\x14\n\x0c\x61\x64\x61pter_type\x18\x02 \x01(\t\"\xa8\x01\n!InvalidConcurrentBatchesConfigMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12I\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32;.v1.public.fields.core_types.InvalidConcurrentBatchesConfig\"W\n\x16InvalidMacroAnnotation\x12\x0b\n\x03msg\x18\x01 \x01(\t\x12\x17\n\x0fmacro_unique_id\x18\x02 \x01(\t\x12\x17\n\x0fmacro_file_path\x18\x03 \x01(\t\"\x98\x01\n\x19InvalidMacroAnnotationMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x41\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x33.v1.public.fields.core_types.InvalidMacroAnnotation\"/\n\x1dGitSparseCheckoutSubdirectory\x12\x0e\n\x06subdir\x18\x01 \x01(\t\"\xa6\x01\n GitSparseCheckoutSubdirectoryMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12H\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32:.v1.public.fields.core_types.GitSparseCheckoutSubdirectory\"/\n\x1bGitProgressCheckoutRevision\x12\x10\n\x08revision\x18\x01 \x01(\t\"\xa2\x01\n\x1eGitProgressCheckoutRevisionMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x46\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x38.v1.public.fields.core_types.GitProgressCheckoutRevision\"4\n%GitProgressUpdatingExistingDependency\x12\x0b\n\x03\x64ir\x18\x01 \x01(\t\"\xb6\x01\n(GitProgressUpdatingExistingDependencyMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12P\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x42.v1.public.fields.core_types.GitProgressUpdatingExistingDependency\".\n\x1fGitProgressPullingNewDependency\x12\x0b\n\x03\x64ir\x18\x01 \x01(\t\"\xaa\x01\n\"GitProgressPullingNewDependencyMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12J\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32<.v1.public.fields.core_types.GitProgressPullingNewDependency\"\x1d\n\x0eGitNothingToDo\x12\x0b\n\x03sha\x18\x01 \x01(\t\"\x88\x01\n\x11GitNothingToDoMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.v1.public.fields.core_types.GitNothingToDo\"E\n\x1fGitProgressUpdatedCheckoutRange\x12\x11\n\tstart_sha\x18\x01 \x01(\t\x12\x0f\n\x07\x65nd_sha\x18\x02 \x01(\t\"\xaa\x01\n\"GitProgressUpdatedCheckoutRangeMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12J\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32<.v1.public.fields.core_types.GitProgressUpdatedCheckoutRange\"*\n\x17GitProgressCheckedOutAt\x12\x0f\n\x07\x65nd_sha\x18\x01 \x01(\t\"\x9a\x01\n\x1aGitProgressCheckedOutAtMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x42\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x34.v1.public.fields.core_types.GitProgressCheckedOutAt\")\n\x1aRegistryProgressGETRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\"\xa0\x01\n\x1dRegistryProgressGETRequestMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x45\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x37.v1.public.fields.core_types.RegistryProgressGETRequest\"=\n\x1bRegistryProgressGETResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x11\n\tresp_code\x18\x02 \x01(\x05\"\xa2\x01\n\x1eRegistryProgressGETResponseMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x46\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x38.v1.public.fields.core_types.RegistryProgressGETResponse\"_\n\x1dSelectorReportInvalidSelector\x12\x17\n\x0fvalid_selectors\x18\x01 \x01(\t\x12\x13\n\x0bspec_method\x18\x02 \x01(\t\x12\x10\n\x08raw_spec\x18\x03 \x01(\t\"\xa6\x01\n SelectorReportInvalidSelectorMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12H\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32:.v1.public.fields.core_types.SelectorReportInvalidSelector\"\x15\n\x13\x44\x65psNoPackagesFound\"\x92\x01\n\x16\x44\x65psNoPackagesFoundMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.core_types.DepsNoPackagesFound\"/\n\x17\x44\x65psStartPackageInstall\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\"\x9a\x01\n\x1a\x44\x65psStartPackageInstallMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x42\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x34.v1.public.fields.core_types.DepsStartPackageInstall\"\'\n\x0f\x44\x65psInstallInfo\x12\x14\n\x0cversion_name\x18\x01 \x01(\t\"\x8a\x01\n\x12\x44\x65psInstallInfoMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.v1.public.fields.core_types.DepsInstallInfo\"-\n\x13\x44\x65psUpdateAvailable\x12\x16\n\x0eversion_latest\x18\x01 \x01(\t\"\x92\x01\n\x16\x44\x65psUpdateAvailableMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.core_types.DepsUpdateAvailable\"\x0e\n\x0c\x44\x65psUpToDate\"\x84\x01\n\x0f\x44\x65psUpToDateMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).v1.public.fields.core_types.DepsUpToDate\",\n\x14\x44\x65psListSubdirectory\x12\x14\n\x0csubdirectory\x18\x01 \x01(\t\"\x94\x01\n\x17\x44\x65psListSubdirectoryMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.v1.public.fields.core_types.DepsListSubdirectory\".\n\x1a\x44\x65psNotifyUpdatesAvailable\x12\x10\n\x08packages\x18\x01 \x03(\t\"\xa0\x01\n\x1d\x44\x65psNotifyUpdatesAvailableMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x45\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x37.v1.public.fields.core_types.DepsNotifyUpdatesAvailable\".\n\x1fRegistryIndexProgressGETRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\"\xaa\x01\n\"RegistryIndexProgressGETRequestMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12J\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32<.v1.public.fields.core_types.RegistryIndexProgressGETRequest\"B\n RegistryIndexProgressGETResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x11\n\tresp_code\x18\x02 \x01(\x05\"\xac\x01\n#RegistryIndexProgressGETResponseMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12K\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32=.v1.public.fields.core_types.RegistryIndexProgressGETResponse\"2\n\x1eRegistryResponseUnexpectedType\x12\x10\n\x08response\x18\x01 \x01(\t\"\xa8\x01\n!RegistryResponseUnexpectedTypeMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12I\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32;.v1.public.fields.core_types.RegistryResponseUnexpectedType\"2\n\x1eRegistryResponseMissingTopKeys\x12\x10\n\x08response\x18\x01 \x01(\t\"\xa8\x01\n!RegistryResponseMissingTopKeysMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12I\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32;.v1.public.fields.core_types.RegistryResponseMissingTopKeys\"5\n!RegistryResponseMissingNestedKeys\x12\x10\n\x08response\x18\x01 \x01(\t\"\xae\x01\n$RegistryResponseMissingNestedKeysMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12L\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32>.v1.public.fields.core_types.RegistryResponseMissingNestedKeys\"3\n\x1fRegistryResponseExtraNestedKeys\x12\x10\n\x08response\x18\x01 \x01(\t\"\xaa\x01\n\"RegistryResponseExtraNestedKeysMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12J\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32<.v1.public.fields.core_types.RegistryResponseExtraNestedKeys\"(\n\x18\x44\x65psSetDownloadDirectory\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x9c\x01\n\x1b\x44\x65psSetDownloadDirectoryMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x43\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x35.v1.public.fields.core_types.DepsSetDownloadDirectory\"-\n\x0c\x44\x65psUnpinned\x12\x10\n\x08revision\x18\x01 \x01(\t\x12\x0b\n\x03git\x18\x02 \x01(\t\"\x84\x01\n\x0f\x44\x65psUnpinnedMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).v1.public.fields.core_types.DepsUnpinned\"/\n\x1bNoNodesForSelectionCriteria\x12\x10\n\x08spec_raw\x18\x01 \x01(\t\"\xa2\x01\n\x1eNoNodesForSelectionCriteriaMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x46\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x38.v1.public.fields.core_types.NoNodesForSelectionCriteria\")\n\x10\x44\x65psLockUpdating\x12\x15\n\rlock_filepath\x18\x01 \x01(\t\"\x8c\x01\n\x13\x44\x65psLockUpdatingMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.v1.public.fields.core_types.DepsLockUpdating\"R\n\x0e\x44\x65psAddPackage\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x19\n\x11packages_filepath\x18\x03 \x01(\t\"\x88\x01\n\x11\x44\x65psAddPackageMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.v1.public.fields.core_types.DepsAddPackage\"\xb7\x01\n\x19\x44\x65psFoundDuplicatePackage\x12\x63\n\x0fremoved_package\x18\x01 \x03(\x0b\x32J.v1.public.fields.core_types.DepsFoundDuplicatePackage.RemovedPackageEntry\x1a\x35\n\x13RemovedPackageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9e\x01\n\x1c\x44\x65psFoundDuplicatePackageMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x44\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x36.v1.public.fields.core_types.DepsFoundDuplicatePackage\"$\n\x12\x44\x65psVersionMissing\x12\x0e\n\x06source\x18\x01 \x01(\t\"\x90\x01\n\x15\x44\x65psVersionMissingMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.v1.public.fields.core_types.DepsVersionMissing\"/\n\x17\x44\x65psScrubbedPackageName\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\"\x9a\x01\n\x1a\x44\x65psScrubbedPackageNameMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x42\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x34.v1.public.fields.core_types.DepsScrubbedPackageName\"?\n\x0f\x41rtifactWritten\x12\x15\n\rartifact_type\x18\x01 \x01(\t\x12\x15\n\rartifact_path\x18\x02 \x01(\t\"\x8a\x01\n\x12\x41rtifactWrittenMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.v1.public.fields.core_types.ArtifactWritten\"*\n\x1bRunningOperationCaughtError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"\xa2\x01\n\x1eRunningOperationCaughtErrorMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x46\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x38.v1.public.fields.core_types.RunningOperationCaughtError\"\x11\n\x0f\x43ompileComplete\"\x8a\x01\n\x12\x43ompileCompleteMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.v1.public.fields.core_types.CompileComplete\"\x18\n\x16\x46reshnessCheckComplete\"\x98\x01\n\x19\x46reshnessCheckCompleteMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x41\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x33.v1.public.fields.core_types.FreshnessCheckComplete\"\x1c\n\nSeedHeader\x12\x0e\n\x06header\x18\x01 \x01(\t\"\x80\x01\n\rSeedHeaderMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.v1.public.fields.core_types.SeedHeader\"m\n\x12SQLRunnerException\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x02 \x01(\t\x12\x38\n\tnode_info\x18\x03 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\"\x90\x01\n\x15SQLRunnerExceptionMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.v1.public.fields.core_types.SQLRunnerException\"\x97\x01\n\x05Group\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cpackage_name\x18\x03 \x01(\t\x12<\n\x05owner\x18\x07 \x03(\x0b\x32-.v1.public.fields.core_types.Group.OwnerEntry\x1a,\n\nOwnerEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x82\x02\n\rLogTestResult\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\x12\n\nnum_models\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12\x14\n\x0cnum_failures\x18\x07 \x01(\x05\x12\x31\n\x05group\x18\x08 \x01(\x0b\x32\".v1.public.fields.core_types.Group\x12\x15\n\rattached_node\x18\t \x01(\t\"\x86\x01\n\x10LogTestResultMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.v1.public.fields.core_types.LogTestResult\"\xb1\x01\n\rLogNodeResult\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12\x0b\n\x03msg\x18\x07 \x01(\t\"\x86\x01\n\x10LogNodeResultMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.v1.public.fields.core_types.LogNodeResult\"{\n\x0cLogStartLine\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"\x84\x01\n\x0fLogStartLineMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).v1.public.fields.core_types.LogStartLine\"\xd8\x01\n\x0eLogModelResult\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12\x31\n\x05group\x18\x07 \x01(\x0b\x32\".v1.public.fields.core_types.Group\"\x88\x01\n\x11LogModelResultMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.v1.public.fields.core_types.LogModelResult\"\xe5\x02\n\x11LogSnapshotResult\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12\x44\n\x03\x63\x66g\x18\x07 \x03(\x0b\x32\x37.v1.public.fields.core_types.LogSnapshotResult.CfgEntry\x12\x16\n\x0eresult_message\x18\x08 \x01(\t\x12\x31\n\x05group\x18\t \x01(\x0b\x32\".v1.public.fields.core_types.Group\x1a*\n\x08\x43\x66gEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8e\x01\n\x14LogSnapshotResultMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..v1.public.fields.core_types.LogSnapshotResult\"\xfc\x01\n\rLogSeedResult\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x16\n\x0eresult_message\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12\x0e\n\x06schema\x18\x07 \x01(\t\x12\x10\n\x08relation\x18\x08 \x01(\t\x12\x31\n\x05group\x18\t \x01(\x0b\x32\".v1.public.fields.core_types.Group\"\x86\x01\n\x10LogSeedResultMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.v1.public.fields.core_types.LogSeedResult\"\xbd\x01\n\x12LogFreshnessResult\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x38\n\tnode_info\x18\x02 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\r\n\x05index\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x05 \x01(\x02\x12\x13\n\x0bsource_name\x18\x06 \x01(\t\x12\x12\n\ntable_name\x18\x07 \x01(\t\"\x90\x01\n\x15LogFreshnessResultMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.v1.public.fields.core_types.LogFreshnessResult\"\xa8\x01\n\x11LogNodeNoOpResult\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\"\x8e\x01\n\x14LogNodeNoOpResultMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..v1.public.fields.core_types.LogNodeNoOpResult\"\"\n\rLogCancelLine\x12\x11\n\tconn_name\x18\x01 \x01(\t\"\x86\x01\n\x10LogCancelLineMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.v1.public.fields.core_types.LogCancelLine\"\x1f\n\x0f\x44\x65\x66\x61ultSelector\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x8a\x01\n\x12\x44\x65\x66\x61ultSelectorMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.v1.public.fields.core_types.DefaultSelector\"E\n\tNodeStart\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\"~\n\x0cNodeStartMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.v1.public.fields.core_types.NodeStart\"\x87\x01\n\x0cNodeFinished\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12=\n\nrun_result\x18\x02 \x01(\x0b\x32).v1.public.fields.core_types.RunResultMsg\"\x84\x01\n\x0fNodeFinishedMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).v1.public.fields.core_types.NodeFinished\"+\n\x1bQueryCancelationUnsupported\x12\x0c\n\x04type\x18\x01 \x01(\t\"\xa2\x01\n\x1eQueryCancelationUnsupportedMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x46\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x38.v1.public.fields.core_types.QueryCancelationUnsupported\"O\n\x0f\x43oncurrencyLine\x12\x13\n\x0bnum_threads\x18\x01 \x01(\x05\x12\x13\n\x0btarget_name\x18\x02 \x01(\t\x12\x12\n\nnode_count\x18\x03 \x01(\x05\"\x8a\x01\n\x12\x43oncurrencyLineMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.v1.public.fields.core_types.ConcurrencyLine\"U\n\x19WritingInjectedSQLForNode\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\"\x9e\x01\n\x1cWritingInjectedSQLForNodeMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x44\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x36.v1.public.fields.core_types.WritingInjectedSQLForNode\"I\n\rNodeCompiling\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\"\x86\x01\n\x10NodeCompilingMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.v1.public.fields.core_types.NodeCompiling\"I\n\rNodeExecuting\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\"\x86\x01\n\x10NodeExecutingMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.v1.public.fields.core_types.NodeExecuting\"}\n\x10LogHookStartLine\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x11\n\tstatement\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"\x8c\x01\n\x13LogHookStartLineMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.v1.public.fields.core_types.LogHookStartLine\"\xa3\x01\n\x0eLogHookEndLine\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x11\n\tstatement\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\"\x88\x01\n\x11LogHookEndLineMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.v1.public.fields.core_types.LogHookEndLine\"\xd6\x01\n\x0fSkippingDetails\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12\x11\n\tnode_name\x18\x04 \x01(\t\x12\r\n\x05index\x18\x05 \x01(\x05\x12\r\n\x05total\x18\x06 \x01(\x05\x12\x31\n\x05group\x18\x07 \x01(\x0b\x32\".v1.public.fields.core_types.Group\"\x8a\x01\n\x12SkippingDetailsMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.v1.public.fields.core_types.SkippingDetails\"\r\n\x0bNothingToDo\"\x82\x01\n\x0eNothingToDoMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.v1.public.fields.core_types.NothingToDo\",\n\x1dRunningOperationUncaughtError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"\xa6\x01\n RunningOperationUncaughtErrorMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12H\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32:.v1.public.fields.core_types.RunningOperationUncaughtError\"\xa3\x01\n\x0c\x45ndRunResult\x12:\n\x07results\x18\x01 \x03(\x0b\x32).v1.public.fields.core_types.RunResultMsg\x12\x14\n\x0c\x65lapsed_time\x18\x02 \x01(\x02\x12\x30\n\x0cgenerated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07success\x18\x04 \x01(\x08\"\x84\x01\n\x0f\x45ndRunResultMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).v1.public.fields.core_types.EndRunResult\"\x11\n\x0fNoNodesSelected\"\x8a\x01\n\x12NoNodesSelectedMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.v1.public.fields.core_types.NoNodesSelected\"w\n\x10\x43ommandCompleted\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x30\n\x0c\x63ompleted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x65lapsed\x18\x04 \x01(\x02\"\x8c\x01\n\x13\x43ommandCompletedMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.v1.public.fields.core_types.CommandCompleted\"z\n\x08ShowNode\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x0f\n\x07preview\x18\x02 \x01(\t\x12\x11\n\tis_inline\x18\x03 \x01(\x08\x12\x15\n\routput_format\x18\x04 \x01(\t\x12\x11\n\tunique_id\x18\x05 \x01(\t\x12\r\n\x05quiet\x18\x06 \x01(\x08\"|\n\x0bShowNodeMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.v1.public.fields.core_types.ShowNode\"\x7f\n\x0c\x43ompiledNode\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x10\n\x08\x63ompiled\x18\x02 \x01(\t\x12\x11\n\tis_inline\x18\x03 \x01(\x08\x12\x15\n\routput_format\x18\x04 \x01(\t\x12\x11\n\tunique_id\x18\x05 \x01(\t\x12\r\n\x05quiet\x18\x06 \x01(\x08\"\x84\x01\n\x0f\x43ompiledNodeMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).v1.public.fields.core_types.CompiledNode\"Y\n\x18SnapshotTimestampWarning\x12\x1f\n\x17snapshot_time_data_type\x18\x01 \x01(\t\x12\x1c\n\x14updated_at_data_type\x18\x02 \x01(\t\"\x9c\x01\n\x1bSnapshotTimestampWarningMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x43\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x35.v1.public.fields.core_types.SnapshotTimestampWarning\"\'\n\x18MicrobatchExecutionDebug\x12\x0b\n\x03msg\x18\x01 \x01(\t\"\x9c\x01\n\x1bMicrobatchExecutionDebugMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x43\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x35.v1.public.fields.core_types.MicrobatchExecutionDebug\"\x8a\x01\n\rLogStartBatch\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0b\x62\x61tch_index\x18\x03 \x01(\x05\x12\x15\n\rtotal_batches\x18\x04 \x01(\x05\"\x86\x01\n\x10LogStartBatchMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.v1.public.fields.core_types.LogStartBatch\"\xe6\x01\n\x0eLogBatchResult\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x13\n\x0b\x62\x61tch_index\x18\x04 \x01(\x05\x12\x15\n\rtotal_batches\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12\x31\n\x05group\x18\x07 \x01(\x0b\x32\".v1.public.fields.core_types.Group\"\x88\x01\n\x11LogBatchResultMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.v1.public.fields.core_types.LogBatchResult\"\xdb\x01\n\x11LogFunctionResult\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12\x31\n\x05group\x18\x07 \x01(\x0b\x32\".v1.public.fields.core_types.Group\"\x8e\x01\n\x14LogFunctionResultMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..v1.public.fields.core_types.LogFunctionResult\"r\n\x17\x43\x61tchableExceptionOnRun\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x03 \x01(\t\"\x9a\x01\n\x1a\x43\x61tchableExceptionOnRunMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x42\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x34.v1.public.fields.core_types.CatchableExceptionOnRun\"o\n\x12InternalErrorOnRun\x12\x12\n\nbuild_path\x18\x01 \x01(\t\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\x12\x38\n\tnode_info\x18\x03 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\"\x90\x01\n\x15InternalErrorOnRunMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.v1.public.fields.core_types.InternalErrorOnRun\"\x85\x01\n\x15GenericExceptionOnRun\x12\x12\n\nbuild_path\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x12\x0b\n\x03\x65xc\x18\x03 \x01(\t\x12\x38\n\tnode_info\x18\x04 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\"\x96\x01\n\x18GenericExceptionOnRunMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.v1.public.fields.core_types.GenericExceptionOnRun\"N\n\x1aNodeConnectionReleaseError\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x03 \x01(\t\"\xa0\x01\n\x1dNodeConnectionReleaseErrorMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x45\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x37.v1.public.fields.core_types.NodeConnectionReleaseError\"\x1f\n\nFoundStats\x12\x11\n\tstat_line\x18\x01 \x01(\t\"\x80\x01\n\rFoundStatsMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.v1.public.fields.core_types.FoundStats\"\x17\n\x15MainKeyboardInterrupt\"\x96\x01\n\x18MainKeyboardInterruptMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.v1.public.fields.core_types.MainKeyboardInterrupt\"#\n\x14MainEncounteredError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"\x94\x01\n\x17MainEncounteredErrorMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.v1.public.fields.core_types.MainEncounteredError\"%\n\x0eMainStackTrace\x12\x13\n\x0bstack_trace\x18\x01 \x01(\t\"\x88\x01\n\x11MainStackTraceMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.v1.public.fields.core_types.MainStackTrace\"\x90\x01\n\x13TimingInfoCollected\x12\x38\n\tnode_info\x18\x01 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12?\n\x0btiming_info\x18\x02 \x01(\x0b\x32*.v1.public.fields.core_types.TimingInfoMsg\"\x92\x01\n\x16TimingInfoCollectedMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.core_types.TimingInfoCollected\"&\n\x12LogDebugStackTrace\x12\x10\n\x08\x65xc_info\x18\x01 \x01(\t\"\x90\x01\n\x15LogDebugStackTraceMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.v1.public.fields.core_types.LogDebugStackTrace\"\x1e\n\x0e\x43heckCleanPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x88\x01\n\x11\x43heckCleanPathMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.v1.public.fields.core_types.CheckCleanPath\" \n\x10\x43onfirmCleanPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x8c\x01\n\x13\x43onfirmCleanPathMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.v1.public.fields.core_types.ConfirmCleanPath\"\"\n\x12ProtectedCleanPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x90\x01\n\x15ProtectedCleanPathMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.v1.public.fields.core_types.ProtectedCleanPath\"\x14\n\x12\x46inishedCleanPaths\"\x90\x01\n\x15\x46inishedCleanPathsMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.v1.public.fields.core_types.FinishedCleanPaths\"5\n\x0bOpenCommand\x12\x10\n\x08open_cmd\x18\x01 \x01(\t\x12\x14\n\x0cprofiles_dir\x18\x02 \x01(\t\"\x82\x01\n\x0eOpenCommandMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.v1.public.fields.core_types.OpenCommand\"0\n\x0fServingDocsPort\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\"\x8a\x01\n\x12ServingDocsPortMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.v1.public.fields.core_types.ServingDocsPort\"%\n\x15ServingDocsAccessInfo\x12\x0c\n\x04port\x18\x01 \x01(\t\"\x96\x01\n\x18ServingDocsAccessInfoMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.v1.public.fields.core_types.ServingDocsAccessInfo\"\x15\n\x13ServingDocsExitInfo\"\x92\x01\n\x16ServingDocsExitInfoMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.core_types.ServingDocsExitInfo\"\xb7\x01\n\x10RunResultWarning\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x38\n\tnode_info\x18\x04 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x31\n\x05group\x18\x05 \x01(\x0b\x32\".v1.public.fields.core_types.Group\"\x8c\x01\n\x13RunResultWarningMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.v1.public.fields.core_types.RunResultWarning\"\xb7\x01\n\x10RunResultFailure\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x38\n\tnode_info\x18\x04 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x31\n\x05group\x18\x05 \x01(\x0b\x32\".v1.public.fields.core_types.Group\"\x8c\x01\n\x13RunResultFailureMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.v1.public.fields.core_types.RunResultFailure\"{\n\tStatsLine\x12@\n\x05stats\x18\x01 \x03(\x0b\x32\x31.v1.public.fields.core_types.StatsLine.StatsEntry\x1a,\n\nStatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"~\n\x0cStatsLineMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.v1.public.fields.core_types.StatsLine\"\x8a\x01\n\x0eRunResultError\x12\x0b\n\x03msg\x18\x01 \x01(\t\x12\x38\n\tnode_info\x18\x02 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\x12\x31\n\x05group\x18\x03 \x01(\x0b\x32\".v1.public.fields.core_types.Group\"\x88\x01\n\x11RunResultErrorMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.v1.public.fields.core_types.RunResultError\"c\n\x17RunResultErrorNoMessage\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x38\n\tnode_info\x18\x02 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\"\x9a\x01\n\x1aRunResultErrorNoMessageMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x42\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x34.v1.public.fields.core_types.RunResultErrorNoMessage\"Y\n\x0fSQLCompiledPath\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x38\n\tnode_info\x18\x02 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\"\x8a\x01\n\x12SQLCompiledPathMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.v1.public.fields.core_types.SQLCompiledPath\"g\n\x14\x43heckNodeTestFailure\x12\x15\n\rrelation_name\x18\x01 \x01(\t\x12\x38\n\tnode_info\x18\x02 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\"\x94\x01\n\x17\x43heckNodeTestFailureMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.v1.public.fields.core_types.CheckNodeTestFailure\"t\n\x0f\x45ndOfRunSummary\x12\x12\n\nnum_errors\x18\x01 \x01(\x05\x12\x14\n\x0cnum_warnings\x18\x02 \x01(\x05\x12\x1a\n\x12keyboard_interrupt\x18\x03 \x01(\x08\x12\x1b\n\x13num_partial_success\x18\x04 \x01(\x05\"\x8a\x01\n\x12\x45ndOfRunSummaryMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.v1.public.fields.core_types.EndOfRunSummary\"w\n\x13MarkSkippedChildren\x12\x11\n\tunique_id\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12=\n\nrun_result\x18\x03 \x01(\x0b\x32).v1.public.fields.core_types.RunResultMsg\"\x92\x01\n\x16MarkSkippedChildrenMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.core_types.MarkSkippedChildren\"\x98\x01\n\x13LogSkipBecauseError\x12\x0e\n\x06schema\x18\x01 \x01(\t\x12\x10\n\x08relation\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x31\n\x05group\x18\x06 \x01(\x0b\x32\".v1.public.fields.core_types.Group\"\x92\x01\n\x16LogSkipBecauseErrorMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.core_types.LogSkipBecauseError\"\x14\n\x12\x45nsureGitInstalled\"\x90\x01\n\x15\x45nsureGitInstalledMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.v1.public.fields.core_types.EnsureGitInstalled\"\x1a\n\x18\x44\x65psCreatingLocalSymlink\"\x9c\x01\n\x1b\x44\x65psCreatingLocalSymlinkMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x43\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x35.v1.public.fields.core_types.DepsCreatingLocalSymlink\"\x19\n\x17\x44\x65psSymlinkNotAvailable\"\x9a\x01\n\x1a\x44\x65psSymlinkNotAvailableMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x42\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x34.v1.public.fields.core_types.DepsSymlinkNotAvailable\"\x11\n\x0f\x44isableTracking\"\x8a\x01\n\x12\x44isableTrackingMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.v1.public.fields.core_types.DisableTracking\"\x1e\n\x0cSendingEvent\x12\x0e\n\x06kwargs\x18\x01 \x01(\t\"\x84\x01\n\x0fSendingEventMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).v1.public.fields.core_types.SendingEvent\"\x12\n\x10SendEventFailure\"\x8c\x01\n\x13SendEventFailureMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.v1.public.fields.core_types.SendEventFailure\"\r\n\x0b\x46lushEvents\"\x82\x01\n\x0e\x46lushEventsMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.v1.public.fields.core_types.FlushEvents\"\x14\n\x12\x46lushEventsFailure\"\x90\x01\n\x15\x46lushEventsFailureMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12=\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32/.v1.public.fields.core_types.FlushEventsFailure\"-\n\x19TrackingInitializeFailure\x12\x10\n\x08\x65xc_info\x18\x01 \x01(\t\"\x9e\x01\n\x1cTrackingInitializeFailureMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x44\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x36.v1.public.fields.core_types.TrackingInitializeFailure\"`\n\x17RunResultWarningMessage\x12\x0b\n\x03msg\x18\x01 \x01(\t\x12\x38\n\tnode_info\x18\x02 \x01(\x0b\x32%.v1.public.fields.core_types.NodeInfo\"\x9a\x01\n\x1aRunResultWarningMessageMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x42\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x34.v1.public.fields.core_types.RunResultWarningMessage\"\x1a\n\x0b\x44\x65\x62ugCmdOut\x12\x0b\n\x03msg\x18\x01 \x01(\t\"\x82\x01\n\x0e\x44\x65\x62ugCmdOutMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.v1.public.fields.core_types.DebugCmdOut\"\x1d\n\x0e\x44\x65\x62ugCmdResult\x12\x0b\n\x03msg\x18\x01 \x01(\t\"\x88\x01\n\x11\x44\x65\x62ugCmdResultMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.v1.public.fields.core_types.DebugCmdResult\"\x19\n\nListCmdOut\x12\x0b\n\x03msg\x18\x01 \x01(\t\"\x80\x01\n\rListCmdOutMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.v1.public.fields.core_types.ListCmdOut\"\xec\x01\n\x0eResourceReport\x12\x14\n\x0c\x63ommand_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63ommand_success\x18\x03 \x01(\x08\x12\x1f\n\x17\x63ommand_wall_clock_time\x18\x04 \x01(\x02\x12\x19\n\x11process_user_time\x18\x05 \x01(\x02\x12\x1b\n\x13process_kernel_time\x18\x06 \x01(\x02\x12\x1b\n\x13process_mem_max_rss\x18\x07 \x01(\x03\x12\x19\n\x11process_in_blocks\x18\x08 \x01(\x03\x12\x1a\n\x12process_out_blocks\x18\t \x01(\x03\"\x88\x01\n\x11ResourceReportMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.v1.public.fields.core_types.ResourceReport\"X\n\x13ObservabilityMetric\x12\r\n\x05label\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02\x12\x0c\n\x04tags\x18\x03 \x03(\t\x12\x15\n\rdebug_message\x18\x04 \x01(\t\"\x92\x01\n\x16ObservabilityMetricMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.core_types.ObservabilityMetric\"\"\n\x13\x41rtifactUploadError\x12\x0b\n\x03msg\x18\x01 \x01(\t\"\x92\x01\n\x16\x41rtifactUploadErrorMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.core_types.ArtifactUploadError\"$\n\x15\x41rtifactUploadSuccess\x12\x0b\n\x03msg\x18\x01 \x01(\t\"\x96\x01\n\x18\x41rtifactUploadSuccessMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.v1.public.fields.core_types.ArtifactUploadSuccess\"$\n\x15\x41rtifactUploadSkipped\x12\x0b\n\x03msg\x18\x01 \x01(\t\"\x96\x01\n\x18\x41rtifactUploadSkippedMsg\x12\x38\n\x04info\x18\x01 \x01(\x0b\x32*.v1.public.fields.core_types.CoreEventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.v1.public.fields.core_types.ArtifactUploadSkippedB>Z<github.com/dbt-labs/proto-golang/v1/public/fields/core_typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.fields.core_types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dbt-labs/proto-golang/v1/public/fields/core_types'
  _globals['_COREEVENTINFO_EXTRAENTRY']._loaded_options = None
  _globals['_COREEVENTINFO_EXTRAENTRY']._serialized_options = b'8\001'
  _globals['_MAINREPORTARGS_ARGSENTRY']._loaded_options = None
  _globals['_MAINREPORTARGS_ARGSENTRY']._serialized_options = b'8\001'
  _globals['_PARTIALPARSINGERROR_EXCINFOENTRY']._loaded_options = None
  _globals['_PARTIALPARSINGERROR_EXCINFOENTRY']._serialized_options = b'8\001'
  _globals['_DEPSFOUNDDUPLICATEPACKAGE_REMOVEDPACKAGEENTRY']._loaded_options = None
  _globals['_DEPSFOUNDDUPLICATEPACKAGE_REMOVEDPACKAGEENTRY']._serialized_options = b'8\001'
  _globals['_GROUP_OWNERENTRY']._loaded_options = None
  _globals['_GROUP_OWNERENTRY']._serialized_options = b'8\001'
  _globals['_LOGSNAPSHOTRESULT_CFGENTRY']._loaded_options = None
  _globals['_LOGSNAPSHOTRESULT_CFGENTRY']._serialized_options = b'8\001'
  _globals['_STATSLINE_STATSENTRY']._loaded_options = None
  _globals['_STATSLINE_STATSENTRY']._serialized_options = b'8\001'
  _globals['_COREEVENTINFO']._serialized_start=144
  _globals['_COREEVENTINFO']._serialized_end=441
  _globals['_COREEVENTINFO_EXTRAENTRY']._serialized_start=397
  _globals['_COREEVENTINFO_EXTRAENTRY']._serialized_end=441
  _globals['_NODERELATION']._serialized_start=443
  _globals['_NODERELATION']._serialized_end=529
  _globals['_NODEINFO']._serialized_start=532
  _globals['_NODEINFO']._serialized_end=844
  _globals['_TIMINGINFOMSG']._serialized_start=846
  _globals['_TIMINGINFOMSG']._serialized_end=973
  _globals['_RUNRESULTMSG']._serialized_start=976
  _globals['_RUNRESULTMSG']._serialized_end=1201
  _globals['_COLUMNTYPE']._serialized_start=1203
  _globals['_COLUMNTYPE']._serialized_end=1295
  _globals['_COLUMNCONSTRAINT']._serialized_start=1297
  _globals['_COLUMNCONSTRAINT']._serialized_end=1386
  _globals['_MODELCONSTRAINT']._serialized_start=1388
  _globals['_MODELCONSTRAINT']._serialized_end=1472
  _globals['_MAINREPORTVERSION']._serialized_start=1474
  _globals['_MAINREPORTVERSION']._serialized_end=1531
  _globals['_MAINREPORTVERSIONMSG']._serialized_start=1534
  _globals['_MAINREPORTVERSIONMSG']._serialized_end=1676
  _globals['_MAINREPORTARGS']._serialized_start=1679
  _globals['_MAINREPORTARGS']._serialized_end=1809
  _globals['_MAINREPORTARGS_ARGSENTRY']._serialized_start=1766
  _globals['_MAINREPORTARGS_ARGSENTRY']._serialized_end=1809
  _globals['_MAINREPORTARGSMSG']._serialized_start=1812
  _globals['_MAINREPORTARGSMSG']._serialized_end=1948
  _globals['_MAINTRACKINGUSERSTATE']._serialized_start=1950
  _globals['_MAINTRACKINGUSERSTATE']._serialized_end=1993
  _globals['_MAINTRACKINGUSERSTATEMSG']._serialized_start=1996
  _globals['_MAINTRACKINGUSERSTATEMSG']._serialized_end=2146
  _globals['_MERGEDFROMSTATE']._serialized_start=2148
  _globals['_MERGEDFROMSTATE']._serialized_end=2201
  _globals['_MERGEDFROMSTATEMSG']._serialized_start=2204
  _globals['_MERGEDFROMSTATEMSG']._serialized_end=2342
  _globals['_MISSINGPROFILETARGET']._serialized_start=2344
  _globals['_MISSINGPROFILETARGET']._serialized_end=2409
  _globals['_MISSINGPROFILETARGETMSG']._serialized_start=2412
  _globals['_MISSINGPROFILETARGETMSG']._serialized_end=2560
  _globals['_INVALIDOPTIONYAML']._serialized_start=2562
  _globals['_INVALIDOPTIONYAML']._serialized_end=2602
  _globals['_INVALIDOPTIONYAMLMSG']._serialized_start=2605
  _globals['_INVALIDOPTIONYAMLMSG']._serialized_end=2747
  _globals['_LOGDBTPROJECTERROR']._serialized_start=2749
  _globals['_LOGDBTPROJECTERROR']._serialized_end=2782
  _globals['_LOGDBTPROJECTERRORMSG']._serialized_start=2785
  _globals['_LOGDBTPROJECTERRORMSG']._serialized_end=2929
  _globals['_LOGDBTPROFILEERROR']._serialized_start=2931
  _globals['_LOGDBTPROFILEERROR']._serialized_end=2982
  _globals['_LOGDBTPROFILEERRORMSG']._serialized_start=2985
  _globals['_LOGDBTPROFILEERRORMSG']._serialized_end=3129
  _globals['_STARTERPROJECTPATH']._serialized_start=3131
  _globals['_STARTERPROJECTPATH']._serialized_end=3164
  _globals['_STARTERPROJECTPATHMSG']._serialized_start=3167
  _globals['_STARTERPROJECTPATHMSG']._serialized_end=3311
  _globals['_CONFIGFOLDERDIRECTORY']._serialized_start=3313
  _globals['_CONFIGFOLDERDIRECTORY']._serialized_end=3349
  _globals['_CONFIGFOLDERDIRECTORYMSG']._serialized_start=3352
  _globals['_CONFIGFOLDERDIRECTORYMSG']._serialized_end=3502
  _globals['_NOSAMPLEPROFILEFOUND']._serialized_start=3504
  _globals['_NOSAMPLEPROFILEFOUND']._serialized_end=3543
  _globals['_NOSAMPLEPROFILEFOUNDMSG']._serialized_start=3546
  _globals['_NOSAMPLEPROFILEFOUNDMSG']._serialized_end=3694
  _globals['_PROFILEWRITTENWITHSAMPLE']._serialized_start=3696
  _globals['_PROFILEWRITTENWITHSAMPLE']._serialized_end=3750
  _globals['_PROFILEWRITTENWITHSAMPLEMSG']._serialized_start=3753
  _globals['_PROFILEWRITTENWITHSAMPLEMSG']._serialized_end=3909
  _globals['_PROFILEWRITTENWITHTARGETTEMPLATEYAML']._serialized_start=3911
  _globals['_PROFILEWRITTENWITHTARGETTEMPLATEYAML']._serialized_end=3977
  _globals['_PROFILEWRITTENWITHTARGETTEMPLATEYAMLMSG']._serialized_start=3980
  _globals['_PROFILEWRITTENWITHTARGETTEMPLATEYAMLMSG']._serialized_end=4160
  _globals['_PROFILEWRITTENWITHPROJECTTEMPLATEYAML']._serialized_start=4162
  _globals['_PROFILEWRITTENWITHPROJECTTEMPLATEYAML']._serialized_end=4229
  _globals['_PROFILEWRITTENWITHPROJECTTEMPLATEYAMLMSG']._serialized_start=4232
  _globals['_PROFILEWRITTENWITHPROJECTTEMPLATEYAMLMSG']._serialized_end=4414
  _globals['_SETTINGUPPROFILE']._serialized_start=4416
  _globals['_SETTINGUPPROFILE']._serialized_end=4434
  _globals['_SETTINGUPPROFILEMSG']._serialized_start=4437
  _globals['_SETTINGUPPROFILEMSG']._serialized_end=4577
  _globals['_INVALIDPROFILETEMPLATEYAML']._serialized_start=4579
  _globals['_INVALIDPROFILETEMPLATEYAML']._serialized_end=4607
  _globals['_INVALIDPROFILETEMPLATEYAMLMSG']._serialized_start=4610
  _globals['_INVALIDPROFILETEMPLATEYAMLMSG']._serialized_end=4770
  _globals['_PROJECTNAMEALREADYEXISTS']._serialized_start=4772
  _globals['_PROJECTNAMEALREADYEXISTS']._serialized_end=4812
  _globals['_PROJECTNAMEALREADYEXISTSMSG']._serialized_start=4815
  _globals['_PROJECTNAMEALREADYEXISTSMSG']._serialized_end=4971
  _globals['_PROJECTCREATED']._serialized_start=4973
  _globals['_PROJECTCREATED']._serialized_end=5048
  _globals['_PROJECTCREATEDMSG']._serialized_start=5051
  _globals['_PROJECTCREATEDMSG']._serialized_end=5187
  _globals['_PACKAGEREDIRECTDEPRECATION']._serialized_start=5189
  _globals['_PACKAGEREDIRECTDEPRECATION']._serialized_end=5253
  _globals['_PACKAGEREDIRECTDEPRECATIONMSG']._serialized_start=5256
  _globals['_PACKAGEREDIRECTDEPRECATIONMSG']._serialized_end=5416
  _globals['_PACKAGEINSTALLPATHDEPRECATION']._serialized_start=5418
  _globals['_PACKAGEINSTALLPATHDEPRECATION']._serialized_end=5449
  _globals['_PACKAGEINSTALLPATHDEPRECATIONMSG']._serialized_start=5452
  _globals['_PACKAGEINSTALLPATHDEPRECATIONMSG']._serialized_end=5618
  _globals['_CONFIGSOURCEPATHDEPRECATION']._serialized_start=5620
  _globals['_CONFIGSOURCEPATHDEPRECATION']._serialized_end=5692
  _globals['_CONFIGSOURCEPATHDEPRECATIONMSG']._serialized_start=5695
  _globals['_CONFIGSOURCEPATHDEPRECATIONMSG']._serialized_end=5857
  _globals['_CONFIGDATAPATHDEPRECATION']._serialized_start=5859
  _globals['_CONFIGDATAPATHDEPRECATION']._serialized_end=5929
  _globals['_CONFIGDATAPATHDEPRECATIONMSG']._serialized_start=5932
  _globals['_CONFIGDATAPATHDEPRECATIONMSG']._serialized_end=6090
  _globals['_METRICATTRIBUTESRENAMED']._serialized_start=6092
  _globals['_METRICATTRIBUTESRENAMED']._serialized_end=6138
  _globals['_METRICATTRIBUTESRENAMEDMSG']._serialized_start=6141
  _globals['_METRICATTRIBUTESRENAMEDMSG']._serialized_end=6295
  _globals['_EXPOSURENAMEDEPRECATION']._serialized_start=6297
  _globals['_EXPOSURENAMEDEPRECATION']._serialized_end=6340
  _globals['_EXPOSURENAMEDEPRECATIONMSG']._serialized_start=6343
  _globals['_EXPOSURENAMEDEPRECATIONMSG']._serialized_end=6497
  _globals['_INTERNALDEPRECATION']._serialized_start=6499
  _globals['_INTERNALDEPRECATION']._serialized_end=6593
  _globals['_INTERNALDEPRECATIONMSG']._serialized_start=6596
  _globals['_INTERNALDEPRECATIONMSG']._serialized_end=6742
  _globals['_ENVIRONMENTVARIABLERENAMED']._serialized_start=6744
  _globals['_ENVIRONMENTVARIABLERENAMED']._serialized_end=6808
  _globals['_ENVIRONMENTVARIABLERENAMEDMSG']._serialized_start=6811
  _globals['_ENVIRONMENTVARIABLERENAMEDMSG']._serialized_end=6971
  _globals['_CONFIGLOGPATHDEPRECATION']._serialized_start=6973
  _globals['_CONFIGLOGPATHDEPRECATION']._serialized_end=7024
  _globals['_CONFIGLOGPATHDEPRECATIONMSG']._serialized_start=7027
  _globals['_CONFIGLOGPATHDEPRECATIONMSG']._serialized_end=7183
  _globals['_CONFIGTARGETPATHDEPRECATION']._serialized_start=7185
  _globals['_CONFIGTARGETPATHDEPRECATION']._serialized_end=7239
  _globals['_CONFIGTARGETPATHDEPRECATIONMSG']._serialized_start=7242
  _globals['_CONFIGTARGETPATHDEPRECATIONMSG']._serialized_end=7404
  _globals['_TESTSCONFIGDEPRECATION']._serialized_start=7406
  _globals['_TESTSCONFIGDEPRECATION']._serialized_end=7473
  _globals['_TESTSCONFIGDEPRECATIONMSG']._serialized_start=7476
  _globals['_TESTSCONFIGDEPRECATIONMSG']._serialized_end=7628
  _globals['_PROJECTFLAGSMOVEDDEPRECATION']._serialized_start=7630
  _globals['_PROJECTFLAGSMOVEDDEPRECATION']._serialized_end=7660
  _globals['_PROJECTFLAGSMOVEDDEPRECATIONMSG']._serialized_start=7663
  _globals['_PROJECTFLAGSMOVEDDEPRECATIONMSG']._serialized_end=7827
  _globals['_SPACESINRESOURCENAMEDEPRECATION']._serialized_start=7829
  _globals['_SPACESINRESOURCENAMEDEPRECATION']._serialized_end=7896
  _globals['_SPACESINRESOURCENAMEDEPRECATIONMSG']._serialized_start=7899
  _globals['_SPACESINRESOURCENAMEDEPRECATIONMSG']._serialized_end=8069
  _globals['_RESOURCENAMESWITHSPACESDEPRECATION']._serialized_start=8071
  _globals['_RESOURCENAMESWITHSPACESDEPRECATION']._serialized_end=8176
  _globals['_RESOURCENAMESWITHSPACESDEPRECATIONMSG']._serialized_start=8179
  _globals['_RESOURCENAMESWITHSPACESDEPRECATIONMSG']._serialized_end=8355
  _globals['_PACKAGEMATERIALIZATIONOVERRIDEDEPRECATION']._serialized_start=8357
  _globals['_PACKAGEMATERIALIZATIONOVERRIDEDEPRECATION']._serialized_end=8452
  _globals['_PACKAGEMATERIALIZATIONOVERRIDEDEPRECATIONMSG']._serialized_start=8455
  _globals['_PACKAGEMATERIALIZATIONOVERRIDEDEPRECATIONMSG']._serialized_end=8645
  _globals['_SOURCEFRESHNESSPROJECTHOOKSNOTRUN']._serialized_start=8647
  _globals['_SOURCEFRESHNESSPROJECTHOOKSNOTRUN']._serialized_end=8682
  _globals['_SOURCEFRESHNESSPROJECTHOOKSNOTRUNMSG']._serialized_start=8685
  _globals['_SOURCEFRESHNESSPROJECTHOOKSNOTRUNMSG']._serialized_end=8859
  _globals['_MFTIMESPINEWITHOUTYAMLCONFIGURATIONDEPRECATION']._serialized_start=8861
  _globals['_MFTIMESPINEWITHOUTYAMLCONFIGURATIONDEPRECATION']._serialized_end=8909
  _globals['_MFTIMESPINEWITHOUTYAMLCONFIGURATIONDEPRECATIONMSG']._serialized_start=8912
  _globals['_MFTIMESPINEWITHOUTYAMLCONFIGURATIONDEPRECATIONMSG']._serialized_end=9112
  _globals['_MFCUMULATIVETYPEPARAMSDEPRECATION']._serialized_start=9114
  _globals['_MFCUMULATIVETYPEPARAMSDEPRECATION']._serialized_end=9149
  _globals['_MFCUMULATIVETYPEPARAMSDEPRECATIONMSG']._serialized_start=9152
  _globals['_MFCUMULATIVETYPEPARAMSDEPRECATIONMSG']._serialized_end=9326
  _globals['_MICROBATCHMACROOUTSIDEOFBATCHESDEPRECATION']._serialized_start=9328
  _globals['_MICROBATCHMACROOUTSIDEOFBATCHESDEPRECATION']._serialized_end=9372
  _globals['_MICROBATCHMACROOUTSIDEOFBATCHESDEPRECATIONMSG']._serialized_start=9375
  _globals['_MICROBATCHMACROOUTSIDEOFBATCHESDEPRECATIONMSG']._serialized_end=9567
  _globals['_GENERICJSONSCHEMAVALIDATIONDEPRECATION']._serialized_start=9569
  _globals['_GENERICJSONSCHEMAVALIDATIONDEPRECATION']._serialized_end=9660
  _globals['_GENERICJSONSCHEMAVALIDATIONDEPRECATIONMSG']._serialized_start=9663
  _globals['_GENERICJSONSCHEMAVALIDATIONDEPRECATIONMSG']._serialized_end=9847
  _globals['_UNEXPECTEDJINJABLOCKDEPRECATION']._serialized_start=9849
  _globals['_UNEXPECTEDJINJABLOCKDEPRECATION']._serialized_end=9909
  _globals['_UNEXPECTEDJINJABLOCKDEPRECATIONMSG']._serialized_start=9912
  _globals['_UNEXPECTEDJINJABLOCKDEPRECATIONMSG']._serialized_end=10082
  _globals['_DUPLICATEYAMLKEYSDEPRECATION']._serialized_start=10084
  _globals['_DUPLICATEYAMLKEYSDEPRECATION']._serialized_end=10159
  _globals['_DUPLICATEYAMLKEYSDEPRECATIONMSG']._serialized_start=10162
  _globals['_DUPLICATEYAMLKEYSDEPRECATIONMSG']._serialized_end=10326
  _globals['_CUSTOMTOPLEVELKEYDEPRECATION']._serialized_start=10328
  _globals['_CUSTOMTOPLEVELKEYDEPRECATION']._serialized_end=10385
  _globals['_CUSTOMTOPLEVELKEYDEPRECATIONMSG']._serialized_start=10388
  _globals['_CUSTOMTOPLEVELKEYDEPRECATIONMSG']._serialized_end=10552
  _globals['_CUSTOMKEYINCONFIGDEPRECATION']._serialized_start=10554
  _globals['_CUSTOMKEYINCONFIGDEPRECATION']._serialized_end=10629
  _globals['_CUSTOMKEYINCONFIGDEPRECATIONMSG']._serialized_start=10632
  _globals['_CUSTOMKEYINCONFIGDEPRECATIONMSG']._serialized_end=10796
  _globals['_CUSTOMKEYINOBJECTDEPRECATION']._serialized_start=10798
  _globals['_CUSTOMKEYINOBJECTDEPRECATION']._serialized_end=10873
  _globals['_CUSTOMKEYINOBJECTDEPRECATIONMSG']._serialized_start=10876
  _globals['_CUSTOMKEYINOBJECTDEPRECATIONMSG']._serialized_end=11040
  _globals['_DEPRECATIONSUMMARY']._serialized_start=11042
  _globals['_DEPRECATIONSUMMARY']._serialized_end=11123
  _globals['_DEPRECATIONSSUMMARY']._serialized_start=11125
  _globals['_DEPRECATIONSSUMMARY']._serialized_end=11237
  _globals['_DEPRECATIONSSUMMARYMSG']._serialized_start=11240
  _globals['_DEPRECATIONSSUMMARYMSG']._serialized_end=11386
  _globals['_CUSTOMOUTPUTPATHINSOURCEFRESHNESSDEPRECATION']._serialized_start=11388
  _globals['_CUSTOMOUTPUTPATHINSOURCEFRESHNESSDEPRECATION']._serialized_end=11448
  _globals['_CUSTOMOUTPUTPATHINSOURCEFRESHNESSDEPRECATIONMSG']._serialized_start=11451
  _globals['_CUSTOMOUTPUTPATHINSOURCEFRESHNESSDEPRECATIONMSG']._serialized_end=11647
  _globals['_PROPERTYMOVEDTOCONFIGDEPRECATION']._serialized_start=11649
  _globals['_PROPERTYMOVEDTOCONFIGDEPRECATION']._serialized_end=11728
  _globals['_PROPERTYMOVEDTOCONFIGDEPRECATIONMSG']._serialized_start=11731
  _globals['_PROPERTYMOVEDTOCONFIGDEPRECATIONMSG']._serialized_end=11903
  _globals['_WEOINCLUDEEXCLUDEDEPRECATION']._serialized_start=11905
  _globals['_WEOINCLUDEEXCLUDEDEPRECATION']._serialized_end=11981
  _globals['_WEOINCLUDEEXCLUDEDEPRECATIONMSG']._serialized_start=11984
  _globals['_WEOINCLUDEEXCLUDEDEPRECATIONMSG']._serialized_end=12148
  _globals['_MODELPARAMUSAGEDEPRECATION']._serialized_start=12150
  _globals['_MODELPARAMUSAGEDEPRECATION']._serialized_end=12178
  _globals['_MODELPARAMUSAGEDEPRECATIONMSG']._serialized_start=12181
  _globals['_MODELPARAMUSAGEDEPRECATIONMSG']._serialized_end=12341
  _globals['_RESOURCETYPESPARAMUSAGEDEPRECATION']._serialized_start=12343
  _globals['_RESOURCETYPESPARAMUSAGEDEPRECATION']._serialized_end=12379
  _globals['_RESOURCETYPESPARAMUSAGEDEPRECATIONMSG']._serialized_start=12382
  _globals['_RESOURCETYPESPARAMUSAGEDEPRECATIONMSG']._serialized_end=12558
  _globals['_MODULESITERTOOLSUSAGEDEPRECATION']._serialized_start=12560
  _globals['_MODULESITERTOOLSUSAGEDEPRECATION']._serialized_end=12594
  _globals['_MODULESITERTOOLSUSAGEDEPRECATIONMSG']._serialized_start=12597
  _globals['_MODULESITERTOOLSUSAGEDEPRECATIONMSG']._serialized_end=12769
  _globals['_SOURCEOVERRIDEDEPRECATION']._serialized_start=12771
  _globals['_SOURCEOVERRIDEDEPRECATION']._serialized_end=12833
  _globals['_SOURCEOVERRIDEDEPRECATIONMSG']._serialized_start=12836
  _globals['_SOURCEOVERRIDEDEPRECATIONMSG']._serialized_end=12994
  _globals['_ENVIRONMENTVARIABLENAMESPACEDEPRECATION']._serialized_start=12996
  _globals['_ENVIRONMENTVARIABLENAMESPACEDEPRECATION']._serialized_end=13079
  _globals['_ENVIRONMENTVARIABLENAMESPACEDEPRECATIONMSG']._serialized_start=13082
  _globals['_ENVIRONMENTVARIABLENAMESPACEDEPRECATIONMSG']._serialized_end=13268
  _globals['_MISSINGPLUSPREFIXDEPRECATION']._serialized_start=13270
  _globals['_MISSINGPLUSPREFIXDEPRECATION']._serialized_end=13345
  _globals['_MISSINGPLUSPREFIXDEPRECATIONMSG']._serialized_start=13348
  _globals['_MISSINGPLUSPREFIXDEPRECATIONMSG']._serialized_end=13512
  _globals['_ARGSPROPERTYINGENERICTESTDEPRECATION']._serialized_start=13514
  _globals['_ARGSPROPERTYINGENERICTESTDEPRECATION']._serialized_end=13566
  _globals['_ARGSPROPERTYINGENERICTESTDEPRECATIONMSG']._serialized_start=13569
  _globals['_ARGSPROPERTYINGENERICTESTDEPRECATIONMSG']._serialized_end=13749
  _globals['_ARGUMENTSPROPERTYINGENERICTESTDEPRECATION']._serialized_start=13751
  _globals['_ARGUMENTSPROPERTYINGENERICTESTDEPRECATION']._serialized_end=13813
  _globals['_ARGUMENTSPROPERTYINGENERICTESTDEPRECATIONMSG']._serialized_start=13816
  _globals['_ARGUMENTSPROPERTYINGENERICTESTDEPRECATIONMSG']._serialized_end=14006
  _globals['_MISSINGARGUMENTSPROPERTYINGENERICTESTDEPRECATION']._serialized_start=14008
  _globals['_MISSINGARGUMENTSPROPERTYINGENERICTESTDEPRECATION']._serialized_end=14077
  _globals['_MISSINGARGUMENTSPROPERTYINGENERICTESTDEPRECATIONMSG']._serialized_start=14080
  _globals['_MISSINGARGUMENTSPROPERTYINGENERICTESTDEPRECATIONMSG']._serialized_end=14284
  _globals['_DUPLICATENAMEDISTINCTNODETYPESDEPRECATION']._serialized_start=14287
  _globals['_DUPLICATENAMEDISTINCTNODETYPESDEPRECATION']._serialized_end=14415
  _globals['_DUPLICATENAMEDISTINCTNODETYPESDEPRECATIONMSG']._serialized_start=14418
  _globals['_DUPLICATENAMEDISTINCTNODETYPESDEPRECATIONMSG']._serialized_end=14608
  _globals['_DEPRECATEDMODEL']._serialized_start=14610
  _globals['_DEPRECATEDMODEL']._serialized_end=14696
  _globals['_DEPRECATEDMODELMSG']._serialized_start=14699
  _globals['_DEPRECATEDMODELMSG']._serialized_end=14837
  _globals['_INPUTFILEDIFFERROR']._serialized_start=14839
  _globals['_INPUTFILEDIFFERROR']._serialized_end=14894
  _globals['_INPUTFILEDIFFERRORMSG']._serialized_start=14897
  _globals['_INPUTFILEDIFFERRORMSG']._serialized_end=15041
  _globals['_INVALIDVALUEFORFIELD']._serialized_start=15043
  _globals['_INVALIDVALUEFORFIELD']._serialized_end=15106
  _globals['_INVALIDVALUEFORFIELDMSG']._serialized_start=15109
  _globals['_INVALIDVALUEFORFIELDMSG']._serialized_end=15257
  _globals['_VALIDATIONWARNING']._serialized_start=15259
  _globals['_VALIDATIONWARNING']._serialized_end=15340
  _globals['_VALIDATIONWARNINGMSG']._serialized_start=15343
  _globals['_VALIDATIONWARNINGMSG']._serialized_end=15485
  _globals['_PARSEPERFINFOPATH']._serialized_start=15487
  _globals['_PARSEPERFINFOPATH']._serialized_end=15520
  _globals['_PARSEPERFINFOPATHMSG']._serialized_start=15523
  _globals['_PARSEPERFINFOPATHMSG']._serialized_end=15665
  _globals['_PARTIALPARSINGERRORPROCESSINGFILE']._serialized_start=15667
  _globals['_PARTIALPARSINGERRORPROCESSINGFILE']._serialized_end=15716
  _globals['_PARTIALPARSINGERRORPROCESSINGFILEMSG']._serialized_start=15719
  _globals['_PARTIALPARSINGERRORPROCESSINGFILEMSG']._serialized_end=15893
  _globals['_PARTIALPARSINGERROR']._serialized_start=15896
  _globals['_PARTIALPARSINGERROR']._serialized_end=16046
  _globals['_PARTIALPARSINGERROR_EXCINFOENTRY']._serialized_start=16000
  _globals['_PARTIALPARSINGERROR_EXCINFOENTRY']._serialized_end=16046
  _globals['_PARTIALPARSINGERRORMSG']._serialized_start=16049
  _globals['_PARTIALPARSINGERRORMSG']._serialized_end=16195
  _globals['_PARTIALPARSINGSKIPPARSING']._serialized_start=16197
  _globals['_PARTIALPARSINGSKIPPARSING']._serialized_end=16224
  _globals['_PARTIALPARSINGSKIPPARSINGMSG']._serialized_start=16227
  _globals['_PARTIALPARSINGSKIPPARSINGMSG']._serialized_end=16385
  _globals['_UNABLETOPARTIALPARSE']._serialized_start=16387
  _globals['_UNABLETOPARTIALPARSE']._serialized_end=16425
  _globals['_UNABLETOPARTIALPARSEMSG']._serialized_start=16428
  _globals['_UNABLETOPARTIALPARSEMSG']._serialized_end=16576
  _globals['_STATECHECKVARSHASH']._serialized_start=16578
  _globals['_STATECHECKVARSHASH']._serialized_end=16680
  _globals['_STATECHECKVARSHASHMSG']._serialized_start=16683
  _globals['_STATECHECKVARSHASHMSG']._serialized_end=16827
  _globals['_PARTIALPARSINGNOTENABLED']._serialized_start=16829
  _globals['_PARTIALPARSINGNOTENABLED']._serialized_end=16855
  _globals['_PARTIALPARSINGNOTENABLEDMSG']._serialized_start=16858
  _globals['_PARTIALPARSINGNOTENABLEDMSG']._serialized_end=17014
  _globals['_PARSEDFILELOADFAILED']._serialized_start=17016
  _globals['_PARSEDFILELOADFAILED']._serialized_end=17083
  _globals['_PARSEDFILELOADFAILEDMSG']._serialized_start=17086
  _globals['_PARSEDFILELOADFAILEDMSG']._serialized_end=17234
  _globals['_PARTIALPARSINGENABLED']._serialized_start=17236
  _globals['_PARTIALPARSINGENABLED']._serialized_end=17308
  _globals['_PARTIALPARSINGENABLEDMSG']._serialized_start=17311
  _globals['_PARTIALPARSINGENABLEDMSG']._serialized_end=17461
  _globals['_PARTIALPARSINGFILE']._serialized_start=17463
  _globals['_PARTIALPARSINGFILE']._serialized_end=17519
  _globals['_PARTIALPARSINGFILEMSG']._serialized_start=17522
  _globals['_PARTIALPARSINGFILEMSG']._serialized_end=17666
  _globals['_INVALIDDISABLEDTARGETINTESTNODE']._serialized_start=17669
  _globals['_INVALIDDISABLEDTARGETINTESTNODE']._serialized_end=17844
  _globals['_INVALIDDISABLEDTARGETINTESTNODEMSG']._serialized_start=17847
  _globals['_INVALIDDISABLEDTARGETINTESTNODEMSG']._serialized_end=18017
  _globals['_UNUSEDRESOURCECONFIGPATH']._serialized_start=18019
  _globals['_UNUSEDRESOURCECONFIGPATH']._serialized_end=18074
  _globals['_UNUSEDRESOURCECONFIGPATHMSG']._serialized_start=18077
  _globals['_UNUSEDRESOURCECONFIGPATHMSG']._serialized_end=18233
  _globals['_SEEDINCREASED']._serialized_start=18235
  _globals['_SEEDINCREASED']._serialized_end=18286
  _globals['_SEEDINCREASEDMSG']._serialized_start=18289
  _globals['_SEEDINCREASEDMSG']._serialized_end=18423
  _globals['_SEEDEXCEEDSLIMITSAMEPATH']._serialized_start=18425
  _globals['_SEEDEXCEEDSLIMITSAMEPATH']._serialized_end=18487
  _globals['_SEEDEXCEEDSLIMITSAMEPATHMSG']._serialized_start=18490
  _globals['_SEEDEXCEEDSLIMITSAMEPATHMSG']._serialized_end=18646
  _globals['_SEEDEXCEEDSLIMITANDPATHCHANGED']._serialized_start=18648
  _globals['_SEEDEXCEEDSLIMITANDPATHCHANGED']._serialized_end=18716
  _globals['_SEEDEXCEEDSLIMITANDPATHCHANGEDMSG']._serialized_start=18719
  _globals['_SEEDEXCEEDSLIMITANDPATHCHANGEDMSG']._serialized_end=18887
  _globals['_SEEDEXCEEDSLIMITCHECKSUMCHANGED']._serialized_start=18889
  _globals['_SEEDEXCEEDSLIMITCHECKSUMCHANGED']._serialized_end=18981
  _globals['_SEEDEXCEEDSLIMITCHECKSUMCHANGEDMSG']._serialized_start=18984
  _globals['_SEEDEXCEEDSLIMITCHECKSUMCHANGEDMSG']._serialized_end=19154
  _globals['_UNUSEDTABLES']._serialized_start=19156
  _globals['_UNUSEDTABLES']._serialized_end=19193
  _globals['_UNUSEDTABLESMSG']._serialized_start=19196
  _globals['_UNUSEDTABLESMSG']._serialized_end=19328
  _globals['_WRONGRESOURCESCHEMAFILE']._serialized_start=19331
  _globals['_WRONGRESOURCESCHEMAFILE']._serialized_end=19466
  _globals['_WRONGRESOURCESCHEMAFILEMSG']._serialized_start=19469
  _globals['_WRONGRESOURCESCHEMAFILEMSG']._serialized_end=19623
  _globals['_NONODEFORYAMLKEY']._serialized_start=19625
  _globals['_NONODEFORYAMLKEY']._serialized_end=19700
  _globals['_NONODEFORYAMLKEYMSG']._serialized_start=19703
  _globals['_NONODEFORYAMLKEYMSG']._serialized_end=19843
  _globals['_MACRONOTFOUNDFORPATCH']._serialized_start=19845
  _globals['_MACRONOTFOUNDFORPATCH']._serialized_end=19888
  _globals['_MACRONOTFOUNDFORPATCHMSG']._serialized_start=19891
  _globals['_MACRONOTFOUNDFORPATCHMSG']._serialized_end=20041
  _globals['_NODENOTFOUNDORDISABLED']._serialized_start=20044
  _globals['_NODENOTFOUNDORDISABLED']._serialized_end=20228
  _globals['_NODENOTFOUNDORDISABLEDMSG']._serialized_start=20231
  _globals['_NODENOTFOUNDORDISABLEDMSG']._serialized_end=20383
  _globals['_JINJALOGWARNING']._serialized_start=20385
  _globals['_JINJALOGWARNING']._serialized_end=20473
  _globals['_JINJALOGWARNINGMSG']._serialized_start=20476
  _globals['_JINJALOGWARNINGMSG']._serialized_end=20614
  _globals['_JINJALOGINFO']._serialized_start=20616
  _globals['_JINJALOGINFO']._serialized_end=20701
  _globals['_JINJALOGINFOMSG']._serialized_start=20704
  _globals['_JINJALOGINFOMSG']._serialized_end=20836
  _globals['_JINJALOGDEBUG']._serialized_start=20838
  _globals['_JINJALOGDEBUG']._serialized_end=20924
  _globals['_JINJALOGDEBUGMSG']._serialized_start=20927
  _globals['_JINJALOGDEBUGMSG']._serialized_end=21061
  _globals['_UNPINNEDREFNEWVERSIONAVAILABLE']._serialized_start=21064
  _globals['_UNPINNEDREFNEWVERSIONAVAILABLE']._serialized_end=21254
  _globals['_UNPINNEDREFNEWVERSIONAVAILABLEMSG']._serialized_start=21257
  _globals['_UNPINNEDREFNEWVERSIONAVAILABLEMSG']._serialized_end=21425
  _globals['_UPCOMINGREFERENCEDEPRECATION']._serialized_start=21428
  _globals['_UPCOMINGREFERENCEDEPRECATION']._serialized_end=21626
  _globals['_UPCOMINGREFERENCEDEPRECATIONMSG']._serialized_start=21629
  _globals['_UPCOMINGREFERENCEDEPRECATIONMSG']._serialized_end=21793
  _globals['_DEPRECATEDREFERENCE']._serialized_start=21796
  _globals['_DEPRECATEDREFERENCE']._serialized_end=21985
  _globals['_DEPRECATEDREFERENCEMSG']._serialized_start=21988
  _globals['_DEPRECATEDREFERENCEMSG']._serialized_end=22134
  _globals['_UNSUPPORTEDCONSTRAINTMATERIALIZATION']._serialized_start=22136
  _globals['_UNSUPPORTEDCONSTRAINTMATERIALIZATION']._serialized_end=22196
  _globals['_UNSUPPORTEDCONSTRAINTMATERIALIZATIONMSG']._serialized_start=22199
  _globals['_UNSUPPORTEDCONSTRAINTMATERIALIZATIONMSG']._serialized_end=22379
  _globals['_PARSEINLINENODEERROR']._serialized_start=22381
  _globals['_PARSEINLINENODEERROR']._serialized_end=22474
  _globals['_PARSEINLINENODEERRORMSG']._serialized_start=22477
  _globals['_PARSEINLINENODEERRORMSG']._serialized_end=22625
  _globals['_SEMANTICVALIDATIONFAILURE']._serialized_start=22627
  _globals['_SEMANTICVALIDATIONFAILURE']._serialized_end=22667
  _globals['_SEMANTICVALIDATIONFAILUREMSG']._serialized_start=22670
  _globals['_SEMANTICVALIDATIONFAILUREMSG']._serialized_end=22828
  _globals['_UNVERSIONEDBREAKINGCHANGE']._serialized_start=22831
  _globals['_UNVERSIONEDBREAKINGCHANGE']._serialized_end=23273
  _globals['_UNVERSIONEDBREAKINGCHANGEMSG']._serialized_start=23276
  _globals['_UNVERSIONEDBREAKINGCHANGEMSG']._serialized_end=23434
  _globals['_WARNSTATETARGETEQUAL']._serialized_start=23436
  _globals['_WARNSTATETARGETEQUAL']._serialized_end=23478
  _globals['_WARNSTATETARGETEQUALMSG']._serialized_start=23481
  _globals['_WARNSTATETARGETEQUALMSG']._serialized_end=23629
  _globals['_FRESHNESSCONFIGPROBLEM']._serialized_start=23631
  _globals['_FRESHNESSCONFIGPROBLEM']._serialized_end=23668
  _globals['_FRESHNESSCONFIGPROBLEMMSG']._serialized_start=23671
  _globals['_FRESHNESSCONFIGPROBLEMMSG']._serialized_end=23823
  _globals['_MICROBATCHMODELNOEVENTTIMEINPUTS']._serialized_start=23825
  _globals['_MICROBATCHMODELNOEVENTTIMEINPUTS']._serialized_end=23879
  _globals['_MICROBATCHMODELNOEVENTTIMEINPUTSMSG']._serialized_start=23882
  _globals['_MICROBATCHMODELNOEVENTTIMEINPUTSMSG']._serialized_end=24054
  _globals['_INVALIDCONCURRENTBATCHESCONFIG']._serialized_start=24056
  _globals['_INVALIDCONCURRENTBATCHESCONFIG']._serialized_end=24130
  _globals['_INVALIDCONCURRENTBATCHESCONFIGMSG']._serialized_start=24133
  _globals['_INVALIDCONCURRENTBATCHESCONFIGMSG']._serialized_end=24301
  _globals['_INVALIDMACROANNOTATION']._serialized_start=24303
  _globals['_INVALIDMACROANNOTATION']._serialized_end=24390
  _globals['_INVALIDMACROANNOTATIONMSG']._serialized_start=24393
  _globals['_INVALIDMACROANNOTATIONMSG']._serialized_end=24545
  _globals['_GITSPARSECHECKOUTSUBDIRECTORY']._serialized_start=24547
  _globals['_GITSPARSECHECKOUTSUBDIRECTORY']._serialized_end=24594
  _globals['_GITSPARSECHECKOUTSUBDIRECTORYMSG']._serialized_start=24597
  _globals['_GITSPARSECHECKOUTSUBDIRECTORYMSG']._serialized_end=24763
  _globals['_GITPROGRESSCHECKOUTREVISION']._serialized_start=24765
  _globals['_GITPROGRESSCHECKOUTREVISION']._serialized_end=24812
  _globals['_GITPROGRESSCHECKOUTREVISIONMSG']._serialized_start=24815
  _globals['_GITPROGRESSCHECKOUTREVISIONMSG']._serialized_end=24977
  _globals['_GITPROGRESSUPDATINGEXISTINGDEPENDENCY']._serialized_start=24979
  _globals['_GITPROGRESSUPDATINGEXISTINGDEPENDENCY']._serialized_end=25031
  _globals['_GITPROGRESSUPDATINGEXISTINGDEPENDENCYMSG']._serialized_start=25034
  _globals['_GITPROGRESSUPDATINGEXISTINGDEPENDENCYMSG']._serialized_end=25216
  _globals['_GITPROGRESSPULLINGNEWDEPENDENCY']._serialized_start=25218
  _globals['_GITPROGRESSPULLINGNEWDEPENDENCY']._serialized_end=25264
  _globals['_GITPROGRESSPULLINGNEWDEPENDENCYMSG']._serialized_start=25267
  _globals['_GITPROGRESSPULLINGNEWDEPENDENCYMSG']._serialized_end=25437
  _globals['_GITNOTHINGTODO']._serialized_start=25439
  _globals['_GITNOTHINGTODO']._serialized_end=25468
  _globals['_GITNOTHINGTODOMSG']._serialized_start=25471
  _globals['_GITNOTHINGTODOMSG']._serialized_end=25607
  _globals['_GITPROGRESSUPDATEDCHECKOUTRANGE']._serialized_start=25609
  _globals['_GITPROGRESSUPDATEDCHECKOUTRANGE']._serialized_end=25678
  _globals['_GITPROGRESSUPDATEDCHECKOUTRANGEMSG']._serialized_start=25681
  _globals['_GITPROGRESSUPDATEDCHECKOUTRANGEMSG']._serialized_end=25851
  _globals['_GITPROGRESSCHECKEDOUTAT']._serialized_start=25853
  _globals['_GITPROGRESSCHECKEDOUTAT']._serialized_end=25895
  _globals['_GITPROGRESSCHECKEDOUTATMSG']._serialized_start=25898
  _globals['_GITPROGRESSCHECKEDOUTATMSG']._serialized_end=26052
  _globals['_REGISTRYPROGRESSGETREQUEST']._serialized_start=26054
  _globals['_REGISTRYPROGRESSGETREQUEST']._serialized_end=26095
  _globals['_REGISTRYPROGRESSGETREQUESTMSG']._serialized_start=26098
  _globals['_REGISTRYPROGRESSGETREQUESTMSG']._serialized_end=26258
  _globals['_REGISTRYPROGRESSGETRESPONSE']._serialized_start=26260
  _globals['_REGISTRYPROGRESSGETRESPONSE']._serialized_end=26321
  _globals['_REGISTRYPROGRESSGETRESPONSEMSG']._serialized_start=26324
  _globals['_REGISTRYPROGRESSGETRESPONSEMSG']._serialized_end=26486
  _globals['_SELECTORREPORTINVALIDSELECTOR']._serialized_start=26488
  _globals['_SELECTORREPORTINVALIDSELECTOR']._serialized_end=26583
  _globals['_SELECTORREPORTINVALIDSELECTORMSG']._serialized_start=26586
  _globals['_SELECTORREPORTINVALIDSELECTORMSG']._serialized_end=26752
  _globals['_DEPSNOPACKAGESFOUND']._serialized_start=26754
  _globals['_DEPSNOPACKAGESFOUND']._serialized_end=26775
  _globals['_DEPSNOPACKAGESFOUNDMSG']._serialized_start=26778
  _globals['_DEPSNOPACKAGESFOUNDMSG']._serialized_end=26924
  _globals['_DEPSSTARTPACKAGEINSTALL']._serialized_start=26926
  _globals['_DEPSSTARTPACKAGEINSTALL']._serialized_end=26973
  _globals['_DEPSSTARTPACKAGEINSTALLMSG']._serialized_start=26976
  _globals['_DEPSSTARTPACKAGEINSTALLMSG']._serialized_end=27130
  _globals['_DEPSINSTALLINFO']._serialized_start=27132
  _globals['_DEPSINSTALLINFO']._serialized_end=27171
  _globals['_DEPSINSTALLINFOMSG']._serialized_start=27174
  _globals['_DEPSINSTALLINFOMSG']._serialized_end=27312
  _globals['_DEPSUPDATEAVAILABLE']._serialized_start=27314
  _globals['_DEPSUPDATEAVAILABLE']._serialized_end=27359
  _globals['_DEPSUPDATEAVAILABLEMSG']._serialized_start=27362
  _globals['_DEPSUPDATEAVAILABLEMSG']._serialized_end=27508
  _globals['_DEPSUPTODATE']._serialized_start=27510
  _globals['_DEPSUPTODATE']._serialized_end=27524
  _globals['_DEPSUPTODATEMSG']._serialized_start=27527
  _globals['_DEPSUPTODATEMSG']._serialized_end=27659
  _globals['_DEPSLISTSUBDIRECTORY']._serialized_start=27661
  _globals['_DEPSLISTSUBDIRECTORY']._serialized_end=27705
  _globals['_DEPSLISTSUBDIRECTORYMSG']._serialized_start=27708
  _globals['_DEPSLISTSUBDIRECTORYMSG']._serialized_end=27856
  _globals['_DEPSNOTIFYUPDATESAVAILABLE']._serialized_start=27858
  _globals['_DEPSNOTIFYUPDATESAVAILABLE']._serialized_end=27904
  _globals['_DEPSNOTIFYUPDATESAVAILABLEMSG']._serialized_start=27907
  _globals['_DEPSNOTIFYUPDATESAVAILABLEMSG']._serialized_end=28067
  _globals['_REGISTRYINDEXPROGRESSGETREQUEST']._serialized_start=28069
  _globals['_REGISTRYINDEXPROGRESSGETREQUEST']._serialized_end=28115
  _globals['_REGISTRYINDEXPROGRESSGETREQUESTMSG']._serialized_start=28118
  _globals['_REGISTRYINDEXPROGRESSGETREQUESTMSG']._serialized_end=28288
  _globals['_REGISTRYINDEXPROGRESSGETRESPONSE']._serialized_start=28290
  _globals['_REGISTRYINDEXPROGRESSGETRESPONSE']._serialized_end=28356
  _globals['_REGISTRYINDEXPROGRESSGETRESPONSEMSG']._serialized_start=28359
  _globals['_REGISTRYINDEXPROGRESSGETRESPONSEMSG']._serialized_end=28531
  _globals['_REGISTRYRESPONSEUNEXPECTEDTYPE']._serialized_start=28533
  _globals['_REGISTRYRESPONSEUNEXPECTEDTYPE']._serialized_end=28583
  _globals['_REGISTRYRESPONSEUNEXPECTEDTYPEMSG']._serialized_start=28586
  _globals['_REGISTRYRESPONSEUNEXPECTEDTYPEMSG']._serialized_end=28754
  _globals['_REGISTRYRESPONSEMISSINGTOPKEYS']._serialized_start=28756
  _globals['_REGISTRYRESPONSEMISSINGTOPKEYS']._serialized_end=28806
  _globals['_REGISTRYRESPONSEMISSINGTOPKEYSMSG']._serialized_start=28809
  _globals['_REGISTRYRESPONSEMISSINGTOPKEYSMSG']._serialized_end=28977
  _globals['_REGISTRYRESPONSEMISSINGNESTEDKEYS']._serialized_start=28979
  _globals['_REGISTRYRESPONSEMISSINGNESTEDKEYS']._serialized_end=29032
  _globals['_REGISTRYRESPONSEMISSINGNESTEDKEYSMSG']._serialized_start=29035
  _globals['_REGISTRYRESPONSEMISSINGNESTEDKEYSMSG']._serialized_end=29209
  _globals['_REGISTRYRESPONSEEXTRANESTEDKEYS']._serialized_start=29211
  _globals['_REGISTRYRESPONSEEXTRANESTEDKEYS']._serialized_end=29262
  _globals['_REGISTRYRESPONSEEXTRANESTEDKEYSMSG']._serialized_start=29265
  _globals['_REGISTRYRESPONSEEXTRANESTEDKEYSMSG']._serialized_end=29435
  _globals['_DEPSSETDOWNLOADDIRECTORY']._serialized_start=29437
  _globals['_DEPSSETDOWNLOADDIRECTORY']._serialized_end=29477
  _globals['_DEPSSETDOWNLOADDIRECTORYMSG']._serialized_start=29480
  _globals['_DEPSSETDOWNLOADDIRECTORYMSG']._serialized_end=29636
  _globals['_DEPSUNPINNED']._serialized_start=29638
  _globals['_DEPSUNPINNED']._serialized_end=29683
  _globals['_DEPSUNPINNEDMSG']._serialized_start=29686
  _globals['_DEPSUNPINNEDMSG']._serialized_end=29818
  _globals['_NONODESFORSELECTIONCRITERIA']._serialized_start=29820
  _globals['_NONODESFORSELECTIONCRITERIA']._serialized_end=29867
  _globals['_NONODESFORSELECTIONCRITERIAMSG']._serialized_start=29870
  _globals['_NONODESFORSELECTIONCRITERIAMSG']._serialized_end=30032
  _globals['_DEPSLOCKUPDATING']._serialized_start=30034
  _globals['_DEPSLOCKUPDATING']._serialized_end=30075
  _globals['_DEPSLOCKUPDATINGMSG']._serialized_start=30078
  _globals['_DEPSLOCKUPDATINGMSG']._serialized_end=30218
  _globals['_DEPSADDPACKAGE']._serialized_start=30220
  _globals['_DEPSADDPACKAGE']._serialized_end=30302
  _globals['_DEPSADDPACKAGEMSG']._serialized_start=30305
  _globals['_DEPSADDPACKAGEMSG']._serialized_end=30441
  _globals['_DEPSFOUNDDUPLICATEPACKAGE']._serialized_start=30444
  _globals['_DEPSFOUNDDUPLICATEPACKAGE']._serialized_end=30627
  _globals['_DEPSFOUNDDUPLICATEPACKAGE_REMOVEDPACKAGEENTRY']._serialized_start=30574
  _globals['_DEPSFOUNDDUPLICATEPACKAGE_REMOVEDPACKAGEENTRY']._serialized_end=30627
  _globals['_DEPSFOUNDDUPLICATEPACKAGEMSG']._serialized_start=30630
  _globals['_DEPSFOUNDDUPLICATEPACKAGEMSG']._serialized_end=30788
  _globals['_DEPSVERSIONMISSING']._serialized_start=30790
  _globals['_DEPSVERSIONMISSING']._serialized_end=30826
  _globals['_DEPSVERSIONMISSINGMSG']._serialized_start=30829
  _globals['_DEPSVERSIONMISSINGMSG']._serialized_end=30973
  _globals['_DEPSSCRUBBEDPACKAGENAME']._serialized_start=30975
  _globals['_DEPSSCRUBBEDPACKAGENAME']._serialized_end=31022
  _globals['_DEPSSCRUBBEDPACKAGENAMEMSG']._serialized_start=31025
  _globals['_DEPSSCRUBBEDPACKAGENAMEMSG']._serialized_end=31179
  _globals['_ARTIFACTWRITTEN']._serialized_start=31181
  _globals['_ARTIFACTWRITTEN']._serialized_end=31244
  _globals['_ARTIFACTWRITTENMSG']._serialized_start=31247
  _globals['_ARTIFACTWRITTENMSG']._serialized_end=31385
  _globals['_RUNNINGOPERATIONCAUGHTERROR']._serialized_start=31387
  _globals['_RUNNINGOPERATIONCAUGHTERROR']._serialized_end=31429
  _globals['_RUNNINGOPERATIONCAUGHTERRORMSG']._serialized_start=31432
  _globals['_RUNNINGOPERATIONCAUGHTERRORMSG']._serialized_end=31594
  _globals['_COMPILECOMPLETE']._serialized_start=31596
  _globals['_COMPILECOMPLETE']._serialized_end=31613
  _globals['_COMPILECOMPLETEMSG']._serialized_start=31616
  _globals['_COMPILECOMPLETEMSG']._serialized_end=31754
  _globals['_FRESHNESSCHECKCOMPLETE']._serialized_start=31756
  _globals['_FRESHNESSCHECKCOMPLETE']._serialized_end=31780
  _globals['_FRESHNESSCHECKCOMPLETEMSG']._serialized_start=31783
  _globals['_FRESHNESSCHECKCOMPLETEMSG']._serialized_end=31935
  _globals['_SEEDHEADER']._serialized_start=31937
  _globals['_SEEDHEADER']._serialized_end=31965
  _globals['_SEEDHEADERMSG']._serialized_start=31968
  _globals['_SEEDHEADERMSG']._serialized_end=32096
  _globals['_SQLRUNNEREXCEPTION']._serialized_start=32098
  _globals['_SQLRUNNEREXCEPTION']._serialized_end=32207
  _globals['_SQLRUNNEREXCEPTIONMSG']._serialized_start=32210
  _globals['_SQLRUNNEREXCEPTIONMSG']._serialized_end=32354
  _globals['_GROUP']._serialized_start=32357
  _globals['_GROUP']._serialized_end=32508
  _globals['_GROUP_OWNERENTRY']._serialized_start=32464
  _globals['_GROUP_OWNERENTRY']._serialized_end=32508
  _globals['_LOGTESTRESULT']._serialized_start=32511
  _globals['_LOGTESTRESULT']._serialized_end=32769
  _globals['_LOGTESTRESULTMSG']._serialized_start=32772
  _globals['_LOGTESTRESULTMSG']._serialized_end=32906
  _globals['_LOGNODERESULT']._serialized_start=32909
  _globals['_LOGNODERESULT']._serialized_end=33086
  _globals['_LOGNODERESULTMSG']._serialized_start=33089
  _globals['_LOGNODERESULTMSG']._serialized_end=33223
  _globals['_LOGSTARTLINE']._serialized_start=33225
  _globals['_LOGSTARTLINE']._serialized_end=33348
  _globals['_LOGSTARTLINEMSG']._serialized_start=33351
  _globals['_LOGSTARTLINEMSG']._serialized_end=33483
  _globals['_LOGMODELRESULT']._serialized_start=33486
  _globals['_LOGMODELRESULT']._serialized_end=33702
  _globals['_LOGMODELRESULTMSG']._serialized_start=33705
  _globals['_LOGMODELRESULTMSG']._serialized_end=33841
  _globals['_LOGSNAPSHOTRESULT']._serialized_start=33844
  _globals['_LOGSNAPSHOTRESULT']._serialized_end=34201
  _globals['_LOGSNAPSHOTRESULT_CFGENTRY']._serialized_start=34159
  _globals['_LOGSNAPSHOTRESULT_CFGENTRY']._serialized_end=34201
  _globals['_LOGSNAPSHOTRESULTMSG']._serialized_start=34204
  _globals['_LOGSNAPSHOTRESULTMSG']._serialized_end=34346
  _globals['_LOGSEEDRESULT']._serialized_start=34349
  _globals['_LOGSEEDRESULT']._serialized_end=34601
  _globals['_LOGSEEDRESULTMSG']._serialized_start=34604
  _globals['_LOGSEEDRESULTMSG']._serialized_end=34738
  _globals['_LOGFRESHNESSRESULT']._serialized_start=34741
  _globals['_LOGFRESHNESSRESULT']._serialized_end=34930
  _globals['_LOGFRESHNESSRESULTMSG']._serialized_start=34933
  _globals['_LOGFRESHNESSRESULTMSG']._serialized_end=35077
  _globals['_LOGNODENOOPRESULT']._serialized_start=35080
  _globals['_LOGNODENOOPRESULT']._serialized_end=35248
  _globals['_LOGNODENOOPRESULTMSG']._serialized_start=35251
  _globals['_LOGNODENOOPRESULTMSG']._serialized_end=35393
  _globals['_LOGCANCELLINE']._serialized_start=35395
  _globals['_LOGCANCELLINE']._serialized_end=35429
  _globals['_LOGCANCELLINEMSG']._serialized_start=35432
  _globals['_LOGCANCELLINEMSG']._serialized_end=35566
  _globals['_DEFAULTSELECTOR']._serialized_start=35568
  _globals['_DEFAULTSELECTOR']._serialized_end=35599
  _globals['_DEFAULTSELECTORMSG']._serialized_start=35602
  _globals['_DEFAULTSELECTORMSG']._serialized_end=35740
  _globals['_NODESTART']._serialized_start=35742
  _globals['_NODESTART']._serialized_end=35811
  _globals['_NODESTARTMSG']._serialized_start=35813
  _globals['_NODESTARTMSG']._serialized_end=35939
  _globals['_NODEFINISHED']._serialized_start=35942
  _globals['_NODEFINISHED']._serialized_end=36077
  _globals['_NODEFINISHEDMSG']._serialized_start=36080
  _globals['_NODEFINISHEDMSG']._serialized_end=36212
  _globals['_QUERYCANCELATIONUNSUPPORTED']._serialized_start=36214
  _globals['_QUERYCANCELATIONUNSUPPORTED']._serialized_end=36257
  _globals['_QUERYCANCELATIONUNSUPPORTEDMSG']._serialized_start=36260
  _globals['_QUERYCANCELATIONUNSUPPORTEDMSG']._serialized_end=36422
  _globals['_CONCURRENCYLINE']._serialized_start=36424
  _globals['_CONCURRENCYLINE']._serialized_end=36503
  _globals['_CONCURRENCYLINEMSG']._serialized_start=36506
  _globals['_CONCURRENCYLINEMSG']._serialized_end=36644
  _globals['_WRITINGINJECTEDSQLFORNODE']._serialized_start=36646
  _globals['_WRITINGINJECTEDSQLFORNODE']._serialized_end=36731
  _globals['_WRITINGINJECTEDSQLFORNODEMSG']._serialized_start=36734
  _globals['_WRITINGINJECTEDSQLFORNODEMSG']._serialized_end=36892
  _globals['_NODECOMPILING']._serialized_start=36894
  _globals['_NODECOMPILING']._serialized_end=36967
  _globals['_NODECOMPILINGMSG']._serialized_start=36970
  _globals['_NODECOMPILINGMSG']._serialized_end=37104
  _globals['_NODEEXECUTING']._serialized_start=37106
  _globals['_NODEEXECUTING']._serialized_end=37179
  _globals['_NODEEXECUTINGMSG']._serialized_start=37182
  _globals['_NODEEXECUTINGMSG']._serialized_end=37316
  _globals['_LOGHOOKSTARTLINE']._serialized_start=37318
  _globals['_LOGHOOKSTARTLINE']._serialized_end=37443
  _globals['_LOGHOOKSTARTLINEMSG']._serialized_start=37446
  _globals['_LOGHOOKSTARTLINEMSG']._serialized_end=37586
  _globals['_LOGHOOKENDLINE']._serialized_start=37589
  _globals['_LOGHOOKENDLINE']._serialized_end=37752
  _globals['_LOGHOOKENDLINEMSG']._serialized_start=37755
  _globals['_LOGHOOKENDLINEMSG']._serialized_end=37891
  _globals['_SKIPPINGDETAILS']._serialized_start=37894
  _globals['_SKIPPINGDETAILS']._serialized_end=38108
  _globals['_SKIPPINGDETAILSMSG']._serialized_start=38111
  _globals['_SKIPPINGDETAILSMSG']._serialized_end=38249
  _globals['_NOTHINGTODO']._serialized_start=38251
  _globals['_NOTHINGTODO']._serialized_end=38264
  _globals['_NOTHINGTODOMSG']._serialized_start=38267
  _globals['_NOTHINGTODOMSG']._serialized_end=38397
  _globals['_RUNNINGOPERATIONUNCAUGHTERROR']._serialized_start=38399
  _globals['_RUNNINGOPERATIONUNCAUGHTERROR']._serialized_end=38443
  _globals['_RUNNINGOPERATIONUNCAUGHTERRORMSG']._serialized_start=38446
  _globals['_RUNNINGOPERATIONUNCAUGHTERRORMSG']._serialized_end=38612
  _globals['_ENDRUNRESULT']._serialized_start=38615
  _globals['_ENDRUNRESULT']._serialized_end=38778
  _globals['_ENDRUNRESULTMSG']._serialized_start=38781
  _globals['_ENDRUNRESULTMSG']._serialized_end=38913
  _globals['_NONODESSELECTED']._serialized_start=38915
  _globals['_NONODESSELECTED']._serialized_end=38932
  _globals['_NONODESSELECTEDMSG']._serialized_start=38935
  _globals['_NONODESSELECTEDMSG']._serialized_end=39073
  _globals['_COMMANDCOMPLETED']._serialized_start=39075
  _globals['_COMMANDCOMPLETED']._serialized_end=39194
  _globals['_COMMANDCOMPLETEDMSG']._serialized_start=39197
  _globals['_COMMANDCOMPLETEDMSG']._serialized_end=39337
  _globals['_SHOWNODE']._serialized_start=39339
  _globals['_SHOWNODE']._serialized_end=39461
  _globals['_SHOWNODEMSG']._serialized_start=39463
  _globals['_SHOWNODEMSG']._serialized_end=39587
  _globals['_COMPILEDNODE']._serialized_start=39589
  _globals['_COMPILEDNODE']._serialized_end=39716
  _globals['_COMPILEDNODEMSG']._serialized_start=39719
  _globals['_COMPILEDNODEMSG']._serialized_end=39851
  _globals['_SNAPSHOTTIMESTAMPWARNING']._serialized_start=39853
  _globals['_SNAPSHOTTIMESTAMPWARNING']._serialized_end=39942
  _globals['_SNAPSHOTTIMESTAMPWARNINGMSG']._serialized_start=39945
  _globals['_SNAPSHOTTIMESTAMPWARNINGMSG']._serialized_end=40101
  _globals['_MICROBATCHEXECUTIONDEBUG']._serialized_start=40103
  _globals['_MICROBATCHEXECUTIONDEBUG']._serialized_end=40142
  _globals['_MICROBATCHEXECUTIONDEBUGMSG']._serialized_start=40145
  _globals['_MICROBATCHEXECUTIONDEBUGMSG']._serialized_end=40301
  _globals['_LOGSTARTBATCH']._serialized_start=40304
  _globals['_LOGSTARTBATCH']._serialized_end=40442
  _globals['_LOGSTARTBATCHMSG']._serialized_start=40445
  _globals['_LOGSTARTBATCHMSG']._serialized_end=40579
  _globals['_LOGBATCHRESULT']._serialized_start=40582
  _globals['_LOGBATCHRESULT']._serialized_end=40812
  _globals['_LOGBATCHRESULTMSG']._serialized_start=40815
  _globals['_LOGBATCHRESULTMSG']._serialized_end=40951
  _globals['_LOGFUNCTIONRESULT']._serialized_start=40954
  _globals['_LOGFUNCTIONRESULT']._serialized_end=41173
  _globals['_LOGFUNCTIONRESULTMSG']._serialized_start=41176
  _globals['_LOGFUNCTIONRESULTMSG']._serialized_end=41318
  _globals['_CATCHABLEEXCEPTIONONRUN']._serialized_start=41320
  _globals['_CATCHABLEEXCEPTIONONRUN']._serialized_end=41434
  _globals['_CATCHABLEEXCEPTIONONRUNMSG']._serialized_start=41437
  _globals['_CATCHABLEEXCEPTIONONRUNMSG']._serialized_end=41591
  _globals['_INTERNALERRORONRUN']._serialized_start=41593
  _globals['_INTERNALERRORONRUN']._serialized_end=41704
  _globals['_INTERNALERRORONRUNMSG']._serialized_start=41707
  _globals['_INTERNALERRORONRUNMSG']._serialized_end=41851
  _globals['_GENERICEXCEPTIONONRUN']._serialized_start=41854
  _globals['_GENERICEXCEPTIONONRUN']._serialized_end=41987
  _globals['_GENERICEXCEPTIONONRUNMSG']._serialized_start=41990
  _globals['_GENERICEXCEPTIONONRUNMSG']._serialized_end=42140
  _globals['_NODECONNECTIONRELEASEERROR']._serialized_start=42142
  _globals['_NODECONNECTIONRELEASEERROR']._serialized_end=42220
  _globals['_NODECONNECTIONRELEASEERRORMSG']._serialized_start=42223
  _globals['_NODECONNECTIONRELEASEERRORMSG']._serialized_end=42383
  _globals['_FOUNDSTATS']._serialized_start=42385
  _globals['_FOUNDSTATS']._serialized_end=42416
  _globals['_FOUNDSTATSMSG']._serialized_start=42419
  _globals['_FOUNDSTATSMSG']._serialized_end=42547
  _globals['_MAINKEYBOARDINTERRUPT']._serialized_start=42549
  _globals['_MAINKEYBOARDINTERRUPT']._serialized_end=42572
  _globals['_MAINKEYBOARDINTERRUPTMSG']._serialized_start=42575
  _globals['_MAINKEYBOARDINTERRUPTMSG']._serialized_end=42725
  _globals['_MAINENCOUNTEREDERROR']._serialized_start=42727
  _globals['_MAINENCOUNTEREDERROR']._serialized_end=42762
  _globals['_MAINENCOUNTEREDERRORMSG']._serialized_start=42765
  _globals['_MAINENCOUNTEREDERRORMSG']._serialized_end=42913
  _globals['_MAINSTACKTRACE']._serialized_start=42915
  _globals['_MAINSTACKTRACE']._serialized_end=42952
  _globals['_MAINSTACKTRACEMSG']._serialized_start=42955
  _globals['_MAINSTACKTRACEMSG']._serialized_end=43091
  _globals['_TIMINGINFOCOLLECTED']._serialized_start=43094
  _globals['_TIMINGINFOCOLLECTED']._serialized_end=43238
  _globals['_TIMINGINFOCOLLECTEDMSG']._serialized_start=43241
  _globals['_TIMINGINFOCOLLECTEDMSG']._serialized_end=43387
  _globals['_LOGDEBUGSTACKTRACE']._serialized_start=43389
  _globals['_LOGDEBUGSTACKTRACE']._serialized_end=43427
  _globals['_LOGDEBUGSTACKTRACEMSG']._serialized_start=43430
  _globals['_LOGDEBUGSTACKTRACEMSG']._serialized_end=43574
  _globals['_CHECKCLEANPATH']._serialized_start=43576
  _globals['_CHECKCLEANPATH']._serialized_end=43606
  _globals['_CHECKCLEANPATHMSG']._serialized_start=43609
  _globals['_CHECKCLEANPATHMSG']._serialized_end=43745
  _globals['_CONFIRMCLEANPATH']._serialized_start=43747
  _globals['_CONFIRMCLEANPATH']._serialized_end=43779
  _globals['_CONFIRMCLEANPATHMSG']._serialized_start=43782
  _globals['_CONFIRMCLEANPATHMSG']._serialized_end=43922
  _globals['_PROTECTEDCLEANPATH']._serialized_start=43924
  _globals['_PROTECTEDCLEANPATH']._serialized_end=43958
  _globals['_PROTECTEDCLEANPATHMSG']._serialized_start=43961
  _globals['_PROTECTEDCLEANPATHMSG']._serialized_end=44105
  _globals['_FINISHEDCLEANPATHS']._serialized_start=44107
  _globals['_FINISHEDCLEANPATHS']._serialized_end=44127
  _globals['_FINISHEDCLEANPATHSMSG']._serialized_start=44130
  _globals['_FINISHEDCLEANPATHSMSG']._serialized_end=44274
  _globals['_OPENCOMMAND']._serialized_start=44276
  _globals['_OPENCOMMAND']._serialized_end=44329
  _globals['_OPENCOMMANDMSG']._serialized_start=44332
  _globals['_OPENCOMMANDMSG']._serialized_end=44462
  _globals['_SERVINGDOCSPORT']._serialized_start=44464
  _globals['_SERVINGDOCSPORT']._serialized_end=44512
  _globals['_SERVINGDOCSPORTMSG']._serialized_start=44515
  _globals['_SERVINGDOCSPORTMSG']._serialized_end=44653
  _globals['_SERVINGDOCSACCESSINFO']._serialized_start=44655
  _globals['_SERVINGDOCSACCESSINFO']._serialized_end=44692
  _globals['_SERVINGDOCSACCESSINFOMSG']._serialized_start=44695
  _globals['_SERVINGDOCSACCESSINFOMSG']._serialized_end=44845
  _globals['_SERVINGDOCSEXITINFO']._serialized_start=44847
  _globals['_SERVINGDOCSEXITINFO']._serialized_end=44868
  _globals['_SERVINGDOCSEXITINFOMSG']._serialized_start=44871
  _globals['_SERVINGDOCSEXITINFOMSG']._serialized_end=45017
  _globals['_RUNRESULTWARNING']._serialized_start=45020
  _globals['_RUNRESULTWARNING']._serialized_end=45203
  _globals['_RUNRESULTWARNINGMSG']._serialized_start=45206
  _globals['_RUNRESULTWARNINGMSG']._serialized_end=45346
  _globals['_RUNRESULTFAILURE']._serialized_start=45349
  _globals['_RUNRESULTFAILURE']._serialized_end=45532
  _globals['_RUNRESULTFAILUREMSG']._serialized_start=45535
  _globals['_RUNRESULTFAILUREMSG']._serialized_end=45675
  _globals['_STATSLINE']._serialized_start=45677
  _globals['_STATSLINE']._serialized_end=45800
  _globals['_STATSLINE_STATSENTRY']._serialized_start=45756
  _globals['_STATSLINE_STATSENTRY']._serialized_end=45800
  _globals['_STATSLINEMSG']._serialized_start=45802
  _globals['_STATSLINEMSG']._serialized_end=45928
  _globals['_RUNRESULTERROR']._serialized_start=45931
  _globals['_RUNRESULTERROR']._serialized_end=46069
  _globals['_RUNRESULTERRORMSG']._serialized_start=46072
  _globals['_RUNRESULTERRORMSG']._serialized_end=46208
  _globals['_RUNRESULTERRORNOMESSAGE']._serialized_start=46210
  _globals['_RUNRESULTERRORNOMESSAGE']._serialized_end=46309
  _globals['_RUNRESULTERRORNOMESSAGEMSG']._serialized_start=46312
  _globals['_RUNRESULTERRORNOMESSAGEMSG']._serialized_end=46466
  _globals['_SQLCOMPILEDPATH']._serialized_start=46468
  _globals['_SQLCOMPILEDPATH']._serialized_end=46557
  _globals['_SQLCOMPILEDPATHMSG']._serialized_start=46560
  _globals['_SQLCOMPILEDPATHMSG']._serialized_end=46698
  _globals['_CHECKNODETESTFAILURE']._serialized_start=46700
  _globals['_CHECKNODETESTFAILURE']._serialized_end=46803
  _globals['_CHECKNODETESTFAILUREMSG']._serialized_start=46806
  _globals['_CHECKNODETESTFAILUREMSG']._serialized_end=46954
  _globals['_ENDOFRUNSUMMARY']._serialized_start=46956
  _globals['_ENDOFRUNSUMMARY']._serialized_end=47072
  _globals['_ENDOFRUNSUMMARYMSG']._serialized_start=47075
  _globals['_ENDOFRUNSUMMARYMSG']._serialized_end=47213
  _globals['_MARKSKIPPEDCHILDREN']._serialized_start=47215
  _globals['_MARKSKIPPEDCHILDREN']._serialized_end=47334
  _globals['_MARKSKIPPEDCHILDRENMSG']._serialized_start=47337
  _globals['_MARKSKIPPEDCHILDRENMSG']._serialized_end=47483
  _globals['_LOGSKIPBECAUSEERROR']._serialized_start=47486
  _globals['_LOGSKIPBECAUSEERROR']._serialized_end=47638
  _globals['_LOGSKIPBECAUSEERRORMSG']._serialized_start=47641
  _globals['_LOGSKIPBECAUSEERRORMSG']._serialized_end=47787
  _globals['_ENSUREGITINSTALLED']._serialized_start=47789
  _globals['_ENSUREGITINSTALLED']._serialized_end=47809
  _globals['_ENSUREGITINSTALLEDMSG']._serialized_start=47812
  _globals['_ENSUREGITINSTALLEDMSG']._serialized_end=47956
  _globals['_DEPSCREATINGLOCALSYMLINK']._serialized_start=47958
  _globals['_DEPSCREATINGLOCALSYMLINK']._serialized_end=47984
  _globals['_DEPSCREATINGLOCALSYMLINKMSG']._serialized_start=47987
  _globals['_DEPSCREATINGLOCALSYMLINKMSG']._serialized_end=48143
  _globals['_DEPSSYMLINKNOTAVAILABLE']._serialized_start=48145
  _globals['_DEPSSYMLINKNOTAVAILABLE']._serialized_end=48170
  _globals['_DEPSSYMLINKNOTAVAILABLEMSG']._serialized_start=48173
  _globals['_DEPSSYMLINKNOTAVAILABLEMSG']._serialized_end=48327
  _globals['_DISABLETRACKING']._serialized_start=48329
  _globals['_DISABLETRACKING']._serialized_end=48346
  _globals['_DISABLETRACKINGMSG']._serialized_start=48349
  _globals['_DISABLETRACKINGMSG']._serialized_end=48487
  _globals['_SENDINGEVENT']._serialized_start=48489
  _globals['_SENDINGEVENT']._serialized_end=48519
  _globals['_SENDINGEVENTMSG']._serialized_start=48522
  _globals['_SENDINGEVENTMSG']._serialized_end=48654
  _globals['_SENDEVENTFAILURE']._serialized_start=48656
  _globals['_SENDEVENTFAILURE']._serialized_end=48674
  _globals['_SENDEVENTFAILUREMSG']._serialized_start=48677
  _globals['_SENDEVENTFAILUREMSG']._serialized_end=48817
  _globals['_FLUSHEVENTS']._serialized_start=48819
  _globals['_FLUSHEVENTS']._serialized_end=48832
  _globals['_FLUSHEVENTSMSG']._serialized_start=48835
  _globals['_FLUSHEVENTSMSG']._serialized_end=48965
  _globals['_FLUSHEVENTSFAILURE']._serialized_start=48967
  _globals['_FLUSHEVENTSFAILURE']._serialized_end=48987
  _globals['_FLUSHEVENTSFAILUREMSG']._serialized_start=48990
  _globals['_FLUSHEVENTSFAILUREMSG']._serialized_end=49134
  _globals['_TRACKINGINITIALIZEFAILURE']._serialized_start=49136
  _globals['_TRACKINGINITIALIZEFAILURE']._serialized_end=49181
  _globals['_TRACKINGINITIALIZEFAILUREMSG']._serialized_start=49184
  _globals['_TRACKINGINITIALIZEFAILUREMSG']._serialized_end=49342
  _globals['_RUNRESULTWARNINGMESSAGE']._serialized_start=49344
  _globals['_RUNRESULTWARNINGMESSAGE']._serialized_end=49440
  _globals['_RUNRESULTWARNINGMESSAGEMSG']._serialized_start=49443
  _globals['_RUNRESULTWARNINGMESSAGEMSG']._serialized_end=49597
  _globals['_DEBUGCMDOUT']._serialized_start=49599
  _globals['_DEBUGCMDOUT']._serialized_end=49625
  _globals['_DEBUGCMDOUTMSG']._serialized_start=49628
  _globals['_DEBUGCMDOUTMSG']._serialized_end=49758
  _globals['_DEBUGCMDRESULT']._serialized_start=49760
  _globals['_DEBUGCMDRESULT']._serialized_end=49789
  _globals['_DEBUGCMDRESULTMSG']._serialized_start=49792
  _globals['_DEBUGCMDRESULTMSG']._serialized_end=49928
  _globals['_LISTCMDOUT']._serialized_start=49930
  _globals['_LISTCMDOUT']._serialized_end=49955
  _globals['_LISTCMDOUTMSG']._serialized_start=49958
  _globals['_LISTCMDOUTMSG']._serialized_end=50086
  _globals['_RESOURCEREPORT']._serialized_start=50089
  _globals['_RESOURCEREPORT']._serialized_end=50325
  _globals['_RESOURCEREPORTMSG']._serialized_start=50328
  _globals['_RESOURCEREPORTMSG']._serialized_end=50464
  _globals['_OBSERVABILITYMETRIC']._serialized_start=50466
  _globals['_OBSERVABILITYMETRIC']._serialized_end=50554
  _globals['_OBSERVABILITYMETRICMSG']._serialized_start=50557
  _globals['_OBSERVABILITYMETRICMSG']._serialized_end=50703
  _globals['_ARTIFACTUPLOADERROR']._serialized_start=50705
  _globals['_ARTIFACTUPLOADERROR']._serialized_end=50739
  _globals['_ARTIFACTUPLOADERRORMSG']._serialized_start=50742
  _globals['_ARTIFACTUPLOADERRORMSG']._serialized_end=50888
  _globals['_ARTIFACTUPLOADSUCCESS']._serialized_start=50890
  _globals['_ARTIFACTUPLOADSUCCESS']._serialized_end=50926
  _globals['_ARTIFACTUPLOADSUCCESSMSG']._serialized_start=50929
  _globals['_ARTIFACTUPLOADSUCCESSMSG']._serialized_end=51079
  _globals['_ARTIFACTUPLOADSKIPPED']._serialized_start=51081
  _globals['_ARTIFACTUPLOADSKIPPED']._serialized_end=51117
  _globals['_ARTIFACTUPLOADSKIPPEDMSG']._serialized_start=51120
  _globals['_ARTIFACTUPLOADSKIPPEDMSG']._serialized_end=51270
# @@protoc_insertion_point(module_scope)
